@@ -33,6 +33,7 @@
 * Include files.
 ******************************************************************************/
 
+#include "cdflib.h"
 #include "widgets.h"
 
 #if defined(mac)
@@ -69,6 +70,7 @@
 #define SETTINGSSEQUENCEqual    21
 #define EPOCHRANGEqual          22
 #define RECORDRANGEqual         23
+#define ZISO8601qual            24
 
 #define FORMATopt               0
 #define NOFORMATopt             1
@@ -114,6 +116,7 @@
 #define NOHEADINGopt            41
 #define ISO8601opt              42
 #define POUNDEDHEADINGopt       43
+#define ZISO8601opt             44
 
 /******************************************************************************
 * Miscellaneous.
@@ -163,7 +166,7 @@
 #define PART3                   3
 #define PART4                   4
 
-#define MAX_ENCODING            ALPHAVMSi_ENCODING
+#define MAX_ENCODING            IA64VMSg_ENCODING
 #define MAX_COMPRESSION         GZIP_COMPRESSION
 #define MAX_CHECKSUM            MD5_CHECKSUM
 #define MAX_SETTINGS_LEN        200
@@ -255,7 +258,7 @@
 #define SAVEkey_SIMPLE                  KB_CTRL_J
 #define RESTOREkey_SIMPLE               KB_CTRL_L
 
-#if defined(alphaosf) || defined(IRIX64bit) || defined(SOLARIS64) || \
+#if defined(alphaosf) || defined(IRIX64bit) || defined(_LP64) || \
     defined(__amd64) || defined(__x86_64__) || defined(__ia64__) || \
     defined(__PPC64__) || defined(__ppc64__)
 #  define Int32FORMATstandard     "%11d"
@@ -298,7 +301,7 @@
 #define OUTPUTitemLEN           6
 
 #define MINitemCOLn             22
-#define MINitemLEN              24      /* Maximum of the possible styles. */
+#define MINitemLEN              24      /* Minimum of the possible styles. */
 #define MAXitemCOLn             47
 #define MAXitemLEN              24      /* Maximum of the possible styles. */
 #define FILTERitemCOLn          72
@@ -636,7 +639,7 @@ struct IndicesStruct {
 * Variable structure.
 ******************************************************************************/
 
-struct VarStruct {
+struct VarStructXP {
   long varN;            /* Number. */
   long numDims;         /* Number of dimensions. */
   long dimSizes[CDF_MAX_DIMS];
@@ -685,14 +688,14 @@ struct VarStruct {
 ******************************************************************************/
 
 struct ItemStruct {
-  int type;                     /* RECORDSt, INDICESt, or VARIABLEt. */
+  int type;                     /* RECORDt, INDICESt, or VARIABLEt. */
   int width;
   Logical outputSetting;        /* Setting on the SelectionWindow. */
   Logical filterSetting;        /* Setting on the SelectionWindow. */
   Logical output;               /* If item should be output. */
   Logical filter;               /* If item should be filtered. */
   Logical inclusive;
-  struct VarStruct *Var;
+  struct VarStructXP *Var;
   struct RecordStruct *Record;
   struct IndicesStruct *Indices;
   struct ItemStruct *nextItem;
@@ -758,13 +761,13 @@ char na[] = "n/a";
 char dots[] = "...";
 char *monos[] = { "n/a", "Unknown", "Increase", "Decrease", "False" };
 char *epochStyles[] = {
-  "standard", "alternate/1", "alternate/2", "alternate/3",
+  "standard", "alternate/1", "alternate/2", "ZISO8601",
   "Format/C_Fortran", "Format/custom", "ISO8601"
 };
 char *encodings[] = {
   NULL, "NETWORK", "SUN", "VAX", "DECSTATION", "SGi", "IBMPC", "IBMRS",
   "HOST", "PPC", NULL, "HP", "NeXT", "ALPHAOSF1", "ALPHAVMSd", "ALPHAVMSg",
-  "ALPHAVMSi", "PowerPC"
+  "ALPHAVMSi", "ARM_LITTLE", "ARM_BIG", "IA64VMSi", "IA64VMSd", "IA64VMSg"
 };
 char *majorities[] = { "input", "row", "column" };
 char *compressions[] = { "no", "rle", "huff", "ahuff", "gzip" };
@@ -808,6 +811,7 @@ int numGroups;
 char ***varsInGroup;
 struct ItemStruct ***varPtrsInGroup;
 int *numVarsInGroup;
+Logical ziso8601;
 #else
 extern int batchMode;
 extern Logical simpleMode;
@@ -864,6 +868,7 @@ extern int numGroups;
 extern char ***varsInGroup;
 extern struct ItemStruct ***varPtrsInGroup;
 extern int *numVarsInGroup;
+extern Logical ziso8601;
 #endif
 
 /******************************************************************************
@@ -879,7 +884,7 @@ void ExportCDFsSpec PROTOARGs((
   char *varHeader0[]
 ));
 void ExportCDF PROTOARGs((char *path, long zMode, Logical negToPosFp0));
-Logical LoadCDF PROTOARGs((void));
+Logical LoadCDF PROTOARGs((CDFid id));
 Logical LoadSelectionWindow PROTOARGs((int part));
 void LoadCDFwindow PROTOARGs((char *path));
 void SelectionWindow PROTOARGs((Logical *noMoreAccess));
@@ -905,18 +910,18 @@ Logical PromptFor PROTOARGs((
   char *value, int valueL, int cursorAt, char *label, int helpID
 ));
 Logical PromptForMinMax PROTOARGs((struct ItemStruct *Item, Logical min));
-Logical PromptForFill PROTOARGs((struct VarStruct *Var));
-Logical PromptForReserve PROTOARGs((struct VarStruct *Var));
-Logical PromptForBlocking PROTOARGs((struct VarStruct *Var));
+Logical PromptForFill PROTOARGs((struct VarStructXP *Var));
+Logical PromptForReserve PROTOARGs((struct VarStructXP *Var));
+Logical PromptForBlocking PROTOARGs((struct VarStructXP *Var));
 Logical PromptForWidth PROTOARGs((struct ItemStruct *Item));
 Logical PromptForFormat PROTOARGs((struct ItemStruct *Item));
 Logical PromptForCompression PROTOARGs((
   long *cType, long cParms[CDF_MAX_PARMS]
 ));
-Logical PromptForSparseness PROTOARGs((struct VarStruct *Var));
+Logical PromptForSparseness PROTOARGs((struct VarStructXP *Var));
 Logical PromptForChecksum PROTOARGs((long *checksum));
 Logical FlipItems PROTOARGs((int itemX));
-int VariableWidth PROTOARGs((struct VarStruct *Var));
+int VariableWidth PROTOARGs((struct VarStructXP *Var));
 void SaveSettings PROTOARGs((void));
 void RestoreSettings PROTOARGs((void));
 Logical ToWalk PROTOARGs((void));
@@ -974,12 +979,12 @@ Logical FirstLastIndices PROTOARGs((
   long numDims, long dimSizes[], long firstIndices[], long lastIndices[],
   long *nValues, Logical toCDF, struct ItemStruct *exportHead
 ));
-Logical ScalarVariable PROTOARGs((struct VarStruct *Var));
-Logical DimensionalVariable PROTOARGs((struct VarStruct *Var, int *dimN));
-Logical OneDimensionVaries PROTOARGs((struct VarStruct *Var));
-Logical ReadScalarValue PROTOARGs((struct VarStruct *Var, long recN));
+Logical ScalarVariable PROTOARGs((struct VarStructXP *Var));
+Logical DimensionalVariable PROTOARGs((struct VarStructXP *Var, int *dimN));
+Logical OneDimensionVaries PROTOARGs((struct VarStructXP *Var));
+Logical ReadScalarValue PROTOARGs((struct VarStructXP *Var, long recN));
 Logical ReadDimensionalValue PROTOARGs((
-  struct VarStruct *Var, long indices[]
+  struct VarStructXP *Var, long indices[]
 ));
 Logical ValidFormat PROTOARGs((char *format));
 Logical SameDimensionalities PROTOARGs((
@@ -999,7 +1004,7 @@ void UpdateToScreen PROTOARGs((
   struct EditWindowStruct *EWscr, char *trailerMsg, long at, long total
 ));
 Logical SetItemMonotonicities PROTOARGs((void));
-Logical SetVarMonotonicity PROTOARGs((struct VarStruct *Var));
+Logical SetVarMonotonicity PROTOARGs((struct VarStructXP *Var));
 void BuildExportList PROTOARGs((
   struct ItemStruct **exportHead, Logical walking
 ));
