@@ -135,13 +135,13 @@ switch (Va->item) {
     CDF = (struct CDFstruct *) cdf_AllocateMemory ((size_t)sizeof(struct CDFstruct), NULL);
     if (CDF == NULL) {
       V_close64 (dotFp, NULL, NULL);
-      DeleteFile (CDFnameX);
+      CDFdeleteFile (CDFnameX);
       return BAD_MALLOC;
     }
     CDF->CDFname = (char *) cdf_AllocateMemory ((size_t)strlen(CDFnameT) + 1, NULL);
     if (CDF->CDFname == NULL) {
       V_close64 (dotFp, NULL, NULL);
-      DeleteFile (CDFnameX);
+      CDFdeleteFile (CDFnameX);
       cdf_FreeMemory (CDF, NULL);
       return BAD_MALLOC;
     }
@@ -199,7 +199,7 @@ switch (Va->item) {
     * Set number of cache buffers based on the CDF's format.
     **************************************************************************/
     if (!CACHEv64(CDF->fp,CDF->workingCacheSize)) {
-      AbortAccess64 (CDF, noUPDATE, DELETE);
+      AbortAccess64 (CDF, noUPDATE, CDFDELETE);
       cdf_FreeMemory (CDF, NULL);
       return BAD_CACHE_SIZE;
     }
@@ -207,12 +207,12 @@ switch (Va->item) {
     * Write magic numbers.
     **************************************************************************/
     if (!Write32_64(CDF->fp,(Int32 *)&magicNumber1)) {
-      AbortAccess64 (CDF, noUPDATE, DELETE);
+      AbortAccess64 (CDF, noUPDATE, CDFDELETE);
       cdf_FreeMemory (CDF, NULL);
       return CDF_WRITE_ERROR;
     }
     if (!Write32_64(CDF->fp,(Int32 *)&magicNumber2u)) {
-      AbortAccess64 (CDF, noUPDATE, DELETE);
+      AbortAccess64 (CDF, noUPDATE, CDFDELETE);
       cdf_FreeMemory (CDF, NULL);
       return CDF_WRITE_ERROR;
     }
@@ -238,7 +238,7 @@ switch (Va->item) {
     if (!sX(WriteCDR64(CDF->fp,V3_CDR_OFFSET64,
 		       CDR_RECORD,&CDR,copyRight,
 		       CDR_NULL),&pStatus)) {
-      AbortAccess64 (CDF, noUPDATE, DELETE);
+      AbortAccess64 (CDF, noUPDATE, CDFDELETE);
       cdf_FreeMemory (CDF, NULL);
       return pStatus;
     }
@@ -246,7 +246,7 @@ switch (Va->item) {
     * Write GDR.
     **************************************************************************/
     CDF->GDRoffset64 = CDR.GDRoffset;
-    GDR.RecordSize = GDR_BASE_SIZE64 + (OFF_T) ((numDims * sizeof(Int32)));
+    GDR.RecordSize = GDR_BASE_SIZE64 + (OFF_T) (numDims * 4);
     GDR.RecordType = GDR_;
     GDR.rVDRhead = (OFF_T) 0;
     GDR.zVDRhead = (OFF_T) 0;
@@ -272,7 +272,7 @@ switch (Va->item) {
     if (!sX(WriteGDR64(CDF->fp,CDF->GDRoffset64,
 		       GDR_RECORD,&GDR,
 		       GDR_NULL),&pStatus)) {
-      AbortAccess64 (CDF, noUPDATE, DELETE);
+      AbortAccess64 (CDF, noUPDATE, CDFDELETE);
       cdf_FreeMemory (CDF, NULL);
       return pStatus;
     }
@@ -284,7 +284,8 @@ switch (Va->item) {
     if (CDF->checksum > 0) {
         if (!sX(CDFsetChecksum(*id, CDF->checksum),&pStatus)) return pStatus;
     }
-    AddOpenCDFsCount();
+    if (!PriorTo ("3.5.0", CDR.Version, CDR.Release, CDR.Increment))
+      AddOpenCDFsCount();
     break;
   }
 
@@ -294,7 +295,7 @@ switch (Va->item) {
   case rVAR_:
   case zVAR_: {
     Logical zOp = (Va->item == zVAR_);
-    long *numOut, zNumDims, *zDimSizes, recVariance,
+    long *numOut, zNumDims = 0L, *zDimSizes = NULL, recVariance,
 	 *dimVariances, newVarNum, numDims;
     char *name, Tname[CDF_VAR_NAME_LEN256+1], pathnameX[DU_MAX_PATH_LEN+1];
     struct CDFstruct *CDF;
@@ -306,7 +307,7 @@ switch (Va->item) {
     int dimN, *max;
     OFF_T offset, ntlOffset, VDRhead;
     int ttmmpp;
-    Int32 padSize, toPad;
+    Int32 padSize;
     void *pad;
     name = va_arg (Va->ap, char *);
     dataType = (Int32) va_arg (Va->ap, long);
@@ -371,6 +372,9 @@ switch (Va->item) {
     * Switch to read-write access if necessary.
     **************************************************************************/
     if (!WriteAccess64(CDF,FALSE,&pStatus)) return pStatus;
+    if (dataType == CDF_TIME_TT2000) {
+      if (!UpdateTT2000header(CDF,&pStatus)) return pStatus;
+    }
     /**************************************************************************
     * Allocate initial/additional pointers to variable data structures.
     **************************************************************************/
@@ -404,19 +408,18 @@ switch (Va->item) {
 	if (varFp == NULL) return VAR_CREATE_ERROR;
       }
       if (!CLOSEv64(varFp,NULL,NULL)) {
-	DeleteFile (pathnameX);
+	CDFdeleteFile (pathnameX);
 	return VAR_CREATE_ERROR;
       }
     }
     /**************************************************************************
     * Write rVDR/zVDR.
     **************************************************************************/
-    if (zOp) ttmmpp = zNumDims * sizeof(Int32);
+    if (zOp) ttmmpp = zNumDims * 4;
     else ttmmpp = 0;
     VDR.RecordSize = BOO(zOp,zVDR_BASE_SIZE64,rVDR_BASE_SIZE64) +
 		     ttmmpp +                                     /*DimSizes.*/
-		     BOO(zOp,zNumDims,
-			     CDF->rNumDims)*sizeof(Int32);	  /*DimVarys.*/
+		     BOO(zOp,zNumDims, CDF->rNumDims)*4;	  /*DimVarys.*/
     VDR.RecordType = BOO(zOp,zVDR_,rVDR_);
     VDR.VDRnext = (OFF_T) 0;
     VDR.DataType = dataType;
@@ -447,18 +450,17 @@ switch (Va->item) {
     padSize = (int) (CDFelemSize(dataType) * numElements);
     pad = (void *) cdf_AllocateMemory((size_t)padSize, NULL);
     if (!sX(AllocateIR64(CDF,VDR.RecordSize+padSize,&offset),&pStatus)) {
-      DeleteFile (pathnameX);
+      CDFdeleteFile (pathnameX);
       AbortAccess64 (CDF, UPDATE, noDELETE);
       return pStatus;
     }
-    toPad = VDR.RecordSize;
     DefaultPadValue(dataType, numElements, pad);
     VDR.RecordSize += padSize;
     SetBit32 (&VDR.Flags,VDR_PADVALUE_BIT);
     if (!sX(WriteVDR64(CDF,CDF->fp,offset,zOp,
 		       VDR_RECORD,&VDR,pad,
 		       VDR_NULL),&pStatus)) {
-      DeleteFile (pathnameX);
+      CDFdeleteFile (pathnameX);
       AbortAccess64 (CDF, UPDATE, noDELETE);
       return pStatus;
     }
