@@ -1339,7 +1339,6 @@ switch (Va->item) {
     if (!sX(ReadVDR(CDF,CDF->fp,offset,zVar,
 		    VDR_FLAGS,&flags,
 		    VDR_DATATYPE,&dataType,
-		    VDR_NUMELEMS,&numElems,
 		    VDR_NULL),&pStatus)) {
       AbortAccess (CDF, UPDATE, noDELETE);
       return pStatus;
@@ -1351,8 +1350,7 @@ switch (Va->item) {
         of the pad value is greater than 16, it causes segmentation fault
         for the IDL CDF interface routine.
     ***********************************************************************/
-    if (STRINGdataType(dataType)) 
-        numElems = 1;
+    numElems = 1;
 
     if (PADvalueBITset(flags)) {
       if (!sX(ReadVDR(CDF,CDF->fp,offset,zVar,
@@ -1370,12 +1368,6 @@ switch (Va->item) {
     }
     else {
       DefaultPadValuePre350 (dataType, numElems, padValue);
-      if (!sX(ConvertBuffer(HostEncoding(),CDF->decoding,
-    		            CDF->negToPosFp0,dataType,
-			    numElems,padValue,padValue),&pStatus)) {
-	    AbortAccess (CDF, UPDATE, noDELETE);
-	return pStatus;
-      }
       sX (NO_PADVALUE_SPECIFIED, &pStatus);
     }
     break;
