@@ -96,7 +96,7 @@ void *buffer;
     fullPhyRec = TRUE;
   /****************************************************************************
   * Determine if only one read is needed.  In order for this to be so...
-  *   1. Full physical records must be being read, and
+  *   2. Full physical records must be being read, and
   *   2a. If the record variance is TRUE, then the record interval must be one
   *       (or a record count of one) so that there is no skipping of records
   *   2b. If the record variance is FALSE.
@@ -111,7 +111,8 @@ void *buffer;
     nRecords = lastHypRec - firstHypRec + 1;
     nValues = (OFF_T) nRecords * Var->NphyRecValues;
     if (!sX(ReadVarValues64(CDF,Var,firstPhyRec,
-			    INT32_ZERO,nValues,buffer),&pStatus)) return pStatus;
+			    INT32_ZERO,nValues,buffer),&pStatus))
+      return pStatus;
     return pStatus;
   }
   /****************************************************************************
@@ -178,8 +179,8 @@ void *buffer;
 STATICforIDL CDFstatus HyperReadDim64 (numDims, dimSizes, dimVarys, indices,
 				       counts, intervals, nHypDimValues,
 				       nPhyDimValues, fullPhyDim, firstDim,
-				       dimIncr, recNum, offset, buffer, phyBuffer,
-				       CDF, Var)
+				       dimIncr, recNum, offset, buffer,
+				       phyBuffer, CDF, Var)
 Int32 numDims;
 Int32 *dimSizes;
 Int32 *dimVarys;
