@@ -440,7 +440,7 @@ int loc;
     FREEFAILED(ptr)
     if (fatalFnc != NULL) {
       char tmp[32+20+1];
-      strcpy (tmp, "Unable to free memory buffer at ");
+      strcpyX (tmp, "Unable to free memory buffer at ", 52);
       snprintf (EofS(tmp), (size_t) sizeof(tmp)-strlen(tmp), "%d", loc);
       (*fatalFnc)(tmp);
     }
