@@ -961,11 +961,14 @@ switch (Va->item) {
   case CDF_MAJORITY_:
   case CDF_FORMAT_:
   case CDF_COMPRESSION_:
+  case CDF_LEAPSECONDLASTUPDATED_:
   case ATTR_NAME_:
   case ATTR_SCOPE_:
   case gENTRY_DATA_:
   case rENTRY_DATA_:
+  case rENTRY_STRINGSDATA_:
   case zENTRY_DATA_:
+  case zENTRY_STRINGSDATA_:
   case gENTRY_DATASPEC_:
   case rENTRY_DATASPEC_:
   case zENTRY_DATASPEC_:
