@@ -177,7 +177,7 @@ switch (Va->item) {
   * CDF_LEAPSECONDLASTUPDATED, 
   ****************************************************************************/
   case CDF_LEAPSECONDLASTUPDATED_: {
-    long lastUpdated = va_arg (Va->ap, long);         /* Compression type. */
+/*    long lastUpdated = va_arg (Va->ap, long);*/       /* Last updated day. */
     break;
   }
   /****************************************************************************
@@ -337,7 +337,7 @@ switch (Va->item) {
 	  return CDF_CREATE_ERROR;
 	}
 	pCount = CompressionParmsCount ((Int32) cType);
-	CPR.RecordSize = CPR_BASE_SIZE + (pCount * sizeof(Int32));
+	CPR.RecordSize = CPR_BASE_SIZE + (pCount * 4);
 	CPR.RecordType = CPR_;
 	CPR.rfuA = 0;
 	CPR.cType = (Int32) cType;
@@ -364,7 +364,7 @@ switch (Va->item) {
   case rVAR_COMPRESSION_:
   case zVAR_COMPRESSION_: {
     Logical zOp = (Va->item == zVAR_COMPRESSION_), zVar;
-    Int32 VDRoffset, maxAllocated, pCount; int p;
+    Int32 VDRoffset, maxAllocated, pCount = 0; int p;
     struct CDFstruct *CDF; struct VarStruct *Var;
     struct VDRstruct VDR; struct CPRstruct CPR;
     long cType = va_arg (Va->ap, long);         /* Compression type. */
@@ -462,7 +462,7 @@ switch (Va->item) {
       case GZIP_COMPRESSION:
 	pCount = CompressionParmsCount ((Int32) cType);
 	SetBit32 (&VDR.Flags, VDR_COMPRESSION_BIT);
-	CPR.RecordSize = CPR_BASE_SIZE + (pCount * sizeof(Int32));
+	CPR.RecordSize = CPR_BASE_SIZE + (pCount * 4);
 	CPR.RecordType = CPR_;
 	CPR.cType = (Int32) cType;
 	CPR.rfuA = 0;
@@ -887,6 +887,13 @@ switch (Va->item) {
 	AEDR.RecordSize = AEDR_BASE_SIZE + nBytesNew;
 	AEDR.DataType = dataType;
 	AEDR.NumElems = numElems;
+        if ((Va->item == rENTRY_DATA_ || Va->item == zENTRY_DATA_) &&
+            STRINGdataType(dataType)) {
+          long numStrings = FindNumberOfItems ((char *)value, numElems,
+                                               STRINGDELIMITER);
+          AEDR.NumStrings = numStrings;
+        } else
+          AEDR.NumStrings = 0;
 	if (!sX(WriteAEDR(CDF,CDF->fp,newOffset,
 			  AEDR_RECORD,&AEDR,value,
 			  AEDR_NULL),&pStatus)) {
@@ -925,6 +932,13 @@ switch (Va->item) {
 	********************************************************************/
 	AEDR.DataType = dataType;
 	AEDR.NumElems = numElems;
+        if ((Va->item == rENTRY_DATA_ || Va->item == zENTRY_DATA_) &&
+            STRINGdataType(dataType)) {
+          long numStrings = FindNumberOfItems ((char *)value, numElems,
+                                               STRINGDELIMITER);
+          AEDR.NumStrings = numStrings;
+        } else
+          AEDR.NumStrings = 0;
 	if (!sX(WriteAEDR(CDF,CDF->fp,eOffset,
 			  AEDR_RECORD,&AEDR,value,
 			  AEDR_NULL),&pStatus)) {
@@ -954,7 +968,13 @@ switch (Va->item) {
       AEDR.DataType = dataType;
       AEDR.Num = entryN;
       AEDR.NumElems = numElems;
-      AEDR.rfuA = 0;
+      if ((Va->item == rENTRY_DATA_ || Va->item == zENTRY_DATA_) &&
+          STRINGdataType(dataType)) {
+        long numStrings = FindNumberOfItems ((char *)value, numElems,
+                                             STRINGDELIMITER);
+        AEDR.NumStrings = numStrings;
+      } else
+        AEDR.NumStrings = 0;
       AEDR.rfuB = 0;
       AEDR.rfuC = 0;
       AEDR.rfuD = -1;
@@ -1034,6 +1054,222 @@ switch (Va->item) {
     }
     break;
   }
+  /****************************************************************************
+   * rENTRY_STRINGSDATA_/zENTRY_STRINGSDATA_, 
+   ****************************************************************************/
+  case rENTRY_STRINGSDATA_:
+  case zENTRY_STRINGSDATA_: {
+    Logical zOp = (Va->item == zENTRY_STRINGSDATA_);
+    struct CDFstruct *CDF;
+    struct ADRstruct ADR;
+    long entryN;                /* True entry number. */
+    Logical zEntry;             /* If true, a AzEDR.  If FALSE, a AgrEDR. */
+    long dataType, numElems;
+    Int32 eOffset;              /* Offset of AEDR. */
+    int ix, length; char *tmpStr, *cstr;
+    long numStrings = va_arg (Va->ap, long);
+    char **values = va_arg (Va->ap, char **);
+    SelectCDF (Cur->cdf, CDF)
+    if (!CURRENTattrSELECTED(CDF)) return NO_ATTR_SELECTED;
+    if ((!zOp?CDF->CURgrEntryNum:CDF->CURzEntryNum) == RESERVED_ENTRYNUM)
+      return NO_ENTRY_SELECTED;
+    if (numStrings < 1) return BAD_NUM_STRINGS;
+    length = 0;
+    for (ix = 0; ix < numStrings; ++ix) {
+      length += (int) strlen(values[ix]);
+    }
+    dataType = CDF_CHAR;
+    numElems = length + (long) strlen(STRINGDELIMITER) * (numStrings-1);
+    tmpStr = (char *) malloc (sizeof(char)*numElems);
+    cstr = tmpStr;
+    for (ix = 0; ix < numStrings; ++ix) {
+      memcpy (cstr, values[ix], strlen(values[ix]));
+      if (ix != (numStrings - 1)) {
+        cstr += strlen(values[ix]);
+        memcpy (cstr, STRINGDELIMITER, strlen(STRINGDELIMITER));
+        cstr += (int) strlen(STRINGDELIMITER);
+      }
+    }
+    if (!sX(ReadADR(CDF->fp,CDF->CURattrOffset,
+                    ADR_RECORD,&ADR,
+                    ADR_NULL),&pStatus)) {
+      AbortAccess (CDF, UPDATE, noDELETE);
+      return pStatus;
+    }
+    if (!WriteAccess(CDF,FALSE,&pStatus)) return pStatus;
+    eOffset = (!zOp?CDF->CURgrEntryOffset:CDF->CURzEntryOffset);
+    if (eOffset != (Int32) RESERVED_ENTRYOFFSET) {
+      /************************************************************************
+       * The entry already exists.
+       ************************************************************************/
+      struct AEDRstruct AEDR; int nBytesCur;
+      if (!sX(ReadAEDR(CDF->fp,eOffset,
+                       AEDR_RECORD,&AEDR,NULL,
+                       AEDR_NULL),&pStatus)) {
+        AbortAccess (CDF, UPDATE, noDELETE);
+        return pStatus;
+      }
+      nBytesCur = (int) (CDFelemSize(AEDR.DataType) * AEDR.NumElems);
+      zEntry = (AEDR.RecordType == AzEDR_);
+      if (numElems != nBytesCur) {
+        /********************************************************************
+         * The size of the new entry value is different than the size of the
+         * old entry value.  The AEDR is changing size.
+         ********************************************************************/
+        Int32 prevOffset, newOffset;
+        if (!sX(FindPrevEntry(CDF,CDF->CURattrOffset,eOffset,
+                              zEntry,&prevOffset),&pStatus)) {
+          AbortAccess (CDF, UPDATE, noDELETE);
+          return pStatus;
+        }
+        if (!sX(ResizeIR(CDF,eOffset,
+                         AEDR_BASE_SIZE+numElems,
+                         &newOffset,TRUE,NULL),&pStatus)) {
+          AbortAccess (CDF, UPDATE, noDELETE);
+          return pStatus;
+        }
+        AEDR.RecordSize = AEDR_BASE_SIZE + numElems;
+        AEDR.DataType = dataType;
+        AEDR.NumElems = numElems;
+        AEDR.NumStrings = numStrings;
+        if (!sX(WriteAEDR(CDF,CDF->fp,newOffset,
+                          AEDR_RECORD,&AEDR,tmpStr,
+                          AEDR_NULL),&pStatus)) {
+          AbortAccess (CDF, UPDATE, noDELETE);
+          return pStatus;
+        }
+        if (!zOp)
+            CDF->CURgrEntryOffset = newOffset;
+        else
+            CDF->CURzEntryOffset = newOffset;
+        if (prevOffset == 0) {
+          if (!sX(WriteADR(CDF->fp,CDF->CURattrOffset,
+                           BOO(zEntry,ADR_AzEDRHEAD,ADR_AgrEDRHEAD),&newOffset,
+                           ADR_NULL),&pStatus)) {
+            AbortAccess (CDF, UPDATE, noDELETE);
+            return pStatus;
+          }
+        }
+        else {
+          if (!sX(WriteAEDR(CDF,CDF->fp,prevOffset,
+                            AEDR_AEDRNEXT,&newOffset,
+                            AEDR_NULL),&pStatus)) {
+            AbortAccess (CDF, UPDATE, noDELETE);
+            return pStatus;
+          }
+        }
+      }
+      else {
+        /********************************************************************
+         * The AEDR is not changing size.
+         ********************************************************************/
+        AEDR.DataType = dataType;
+        AEDR.NumElems = numElems;
+        AEDR.NumStrings = numStrings;
+        if (!sX(WriteAEDR(CDF,CDF->fp,eOffset,
+                          AEDR_RECORD,&AEDR,tmpStr,
+                          AEDR_NULL),&pStatus)) {
+          AbortAccess (CDF, UPDATE, noDELETE);
+          return pStatus;
+        }
+      }
+    }
+    else {
+      /************************************************************************
+       * The entry does not exist.
+       ************************************************************************/
+      struct AEDRstruct AEDR;
+      Int32 lastOffset;
+      zEntry = BOO(!zOp,FALSE, BOO(zModeON(CDF),
+                   BOO(CDF->CURzEntryNum < CDF->NrVars,FALSE,TRUE),TRUE));
+      entryN = BOO(!zOp,CDF->CURgrEntryNum,
+                   BOO(zModeON(CDF), BOO(CDF->CURzEntryNum < CDF->NrVars,
+                                         CDF->CURzEntryNum,CDF->CURzEntryNum -
+                                                           CDF->NrVars),
+                                         CDF->CURzEntryNum));
+      AEDR.RecordSize = AEDR_BASE_SIZE + numElems;
+      AEDR.RecordType = BOO(zEntry,AzEDR_,AgrEDR_);
+      AEDR.AEDRnext = (Int32) 0;
+      AEDR.AttrNum = ADR.Num;
+      AEDR.DataType = dataType;
+      AEDR.Num = entryN;
+      AEDR.NumElems = numElems;
+      AEDR.NumStrings = numStrings;
+      AEDR.rfuB = 0;
+      AEDR.rfuC = 0;
+      AEDR.rfuD = -1;
+      AEDR.rfuE = -1;
+      if (!sX(AllocateIR(CDF,AEDR.RecordSize,&eOffset),&pStatus)) {
+        AbortAccess (CDF, UPDATE, noDELETE);
+        return pStatus;
+      }
+      if (!sX(WriteAEDR(CDF,CDF->fp,eOffset,
+                        AEDR_RECORD,&AEDR,tmpStr,
+                        AEDR_NULL),&pStatus)) {
+        AbortAccess (CDF, UPDATE, noDELETE);
+        return pStatus;
+      }
+      if (!zOp)
+          CDF->CURgrEntryOffset = eOffset;
+      else
+          CDF->CURzEntryOffset = eOffset;
+      if (!sX(FindLastEntry(CDF,CDF->CURattrOffset,
+                            zEntry,&lastOffset),&pStatus)) {
+        AbortAccess (CDF, UPDATE, noDELETE);
+        return pStatus;
+      }
+      if (lastOffset == (Int32) 0) {
+        /********************************************************************
+         * This is the first entry (of this type).  The ADR will point to
+         * this entry.
+         ********************************************************************/
+        if (zEntry) {
+          ADR.NzEntries = 1;
+          ADR.MAXzEntry = entryN;
+          ADR.AzEDRhead = eOffset;
+        }
+        else {
+          ADR.NgrEntries = 1;
+          ADR.MAXgrEntry = entryN;
+          ADR.AgrEDRhead = eOffset;
+        }
+        if (!sX(WriteADR(CDF->fp,CDF->CURattrOffset,
+                         ADR_RECORD,&ADR,
+                         ADR_NULL),&pStatus)) {
+          AbortAccess (CDF, UPDATE, noDELETE);
+          return pStatus;
+        }
+      }
+      else {
+        /********************************************************************
+         * Entries already exist (of this type).  The currently last entry
+         * will point to this entry.
+         ********************************************************************/
+        if (zEntry) {
+          ADR.NzEntries++;
+          ADR.MAXzEntry = MAXIMUM(ADR.MAXzEntry,entryN);
+        }
+        else {
+          ADR.NgrEntries++;
+          ADR.MAXgrEntry = MAXIMUM(ADR.MAXgrEntry,entryN);
+        }
+        if (!sX(WriteADR(CDF->fp,CDF->CURattrOffset,
+                         ADR_RECORD,&ADR,
+                         ADR_NULL),&pStatus)) {
+          AbortAccess (CDF, UPDATE, noDELETE);
+          return pStatus;
+        }
+        if (!sX(WriteAEDR(CDF,CDF->fp,lastOffset,
+                          AEDR_AEDRNEXT,&eOffset,
+                          AEDR_NULL),&pStatus)) {
+          AbortAccess (CDF, UPDATE, noDELETE);
+          return pStatus;
+        }
+      }
+    }
+    free (tmpStr);
+    break;
+  }
 }
 return pStatus;
 }
