@@ -115,7 +115,7 @@ vFILE *fp;
 Int32 offset;
 Int32 *irType;
 {
-  long irTypeOffset = offset + sizeof(Int32);
+  long irTypeOffset = offset + 4;
   if (!SEEKv(fp,irTypeOffset,vSEEK_SET)) return CRE;
   if (!Read32(fp,irType)) return CRE;
   return CDF_OK;
@@ -829,7 +829,7 @@ va_dcl
              if (!Read32(fp,&(AEDR->DataType))) return CRE;
              if (!Read32(fp,&(AEDR->Num))) return CRE;
              if (!Read32(fp,&(AEDR->NumElems))) return CRE;
-             if (!Read32(fp,&(AEDR->rfuA))) return CRE;
+             if (!Read32(fp,&(AEDR->NumStrings))) return CRE;
              if (!Read32(fp,&(AEDR->rfuB))) return CRE;
              if (!Read32(fp,&(AEDR->rfuC))) return CRE;
              if (!Read32(fp,&(AEDR->rfuD))) return CRE;
@@ -839,8 +839,8 @@ va_dcl
                                   AEDR->NumElems);
                if (!READv(value,nBytes,1,fp)) return CRE;
                if (STRINGdataType(AEDR->DataType)) {
-                 FillSpacesToString((char *)value, (int)AEDR->NumElems,
-                                    (int)AEDR->NumElems);
+                 FillNulsToString((char *)value, (int)AEDR->NumElems,
+                                  (int)AEDR->NumElems);
                }
 
              };
@@ -854,7 +854,7 @@ va_dcl
              AEDR->DataType = CurAEDR->AEDR.DataType;
              AEDR->Num = CurAEDR->AEDR.Num;
              AEDR->NumElems = CurAEDR->AEDR.NumElems;
-             AEDR->rfuA = CurAEDR->AEDR.rfuA;
+             AEDR->NumStrings = CurAEDR->AEDR.NumStrings;
              AEDR->rfuB = CurAEDR->AEDR.rfuB;
              AEDR->rfuC = CurAEDR->AEDR.rfuC;
              AEDR->rfuD = CurAEDR->AEDR.rfuD;
@@ -879,7 +879,7 @@ va_dcl
 	     nBytes = (size_t) (CDFelemSize(dataType) * numElems);
 	     if (!READv(value,nBytes,1,fp)) return CRE;
              if (STRINGdataType(dataType)) {
-               FillSpacesToString((char *)value, (int)numElems, (int)numElems);
+               FillNulsToString((char *)value, (int)numElems, (int)numElems);
              }
          }
          else
@@ -968,6 +968,17 @@ va_dcl
                };
                break;
            }
+           case AEDR_NUMSTRINGS: {
+               if (read_only_mode == READONLYoff)
+               {
+                   tOffset += (OFF_T) AEDR_NUMSTRINGS_OFFSET; break;
+               }
+               else
+               {
+                   *buffer = CurAEDR->AEDR.NumStrings;
+               }
+               break;
+           }
 	   default: return CDF_INTERNAL_ERROR;
 	 }
          if (read_only_mode == READONLYoff)
@@ -1065,8 +1076,8 @@ va_dcl
 	   size_t nBytes = (size_t) (CDFelemSize(VDR->DataType)*VDR->NumElems);
 	   if (!READv(padValue,nBytes,1,fp)) return CRE;
            if (STRINGdataType(VDR->DataType)) {
-             FillSpacesToString((char *)padValue, (int)VDR->NumElems,
-                                (int)VDR->NumElems);
+             FillNulsToString((char *)padValue, (int)VDR->NumElems,
+                              (int)VDR->NumElems);
            }
 	 }
 	 break;
@@ -1111,7 +1122,7 @@ va_dcl
 	   if (!sX(ReadVDR(CDF,fp,offset,zVar,
 			   VDR_zNUMDIMS,&nDims,
 			   VDR_NULL),&pStatus)) return pStatus;
-	   tOffset = offset + zVDR_DIMVARYS_OFFSETb + (nDims*sizeof(Int32)) +
+	   tOffset = offset + zVDR_DIMVARYS_OFFSETb + (nDims*4) +
 		     BOO(CDF->wastedSpace,VDR_WASTED_SIZE,0);
 	 }
 	 else {
@@ -1144,8 +1155,7 @@ va_dcl
 			   VDR_zNUMDIMS,&zNumDims,
 			   VDR_NULL),&pStatus)) return pStatus;
 	   tOffset = offset + zVDR_PADVALUE_OFFSETb +
-		     (zNumDims*sizeof(Int32)) +
-		     (zNumDims*sizeof(Int32)) +
+		     (zNumDims*4) + (zNumDims*4) +
 		     BOO(CDF->wastedSpace,VDR_WASTED_SIZE,0);
 	 }
 	 else {
@@ -1157,15 +1167,14 @@ va_dcl
 			   GDR_rNUMDIMS,&rNumDims,
 			   GDR_NULL),&pStatus)) return pStatus;
 	   tOffset = offset + rVDR_PADVALUE_OFFSETb +
-		     (rNumDims*sizeof(Int32)) +
-		     BOO(CDF->wastedSpace,VDR_WASTED_SIZE,0);
+		     (rNumDims*4) + BOO(CDF->wastedSpace,VDR_WASTED_SIZE,0);
 	 }
 	 if (!SEEKv(fp,tOffset,vSEEK_SET)) return CRE;
 	 nBytes = (size_t) (CDFelemSize(dataType) * numElems);
 	 if (!READv(padValue,nBytes,1,fp)) return CRE;
          if (STRINGdataType(dataType)) {
-           FillSpacesToString((char *)padValue, (int)numElems,
-                              (int)numElems);
+           FillNulsToString((char *)padValue, (int)numElems,
+                            (int)numElems);
          }
 	 break;
        }
@@ -1258,8 +1267,8 @@ va_dcl
 			 VXR_NULL),&pStatus)) return pStatus;
 	 switch (field) {
 	   case VXR_FIRSTREC: break;
-	   case VXR_LASTREC: tOffset += nEntries * sizeof(Int32); break;
-	   case VXR_OFFSET: tOffset += 2 * nEntries * sizeof(Int32); break;
+	   case VXR_LASTREC: tOffset += nEntries * 4; break;
+	   case VXR_OFFSET: tOffset += 2 * nEntries * 4; break;
 	   default: return CDF_INTERNAL_ERROR;
 	 }
 	 if (!SEEKv(fp,tOffset,vSEEK_SET)) return CRE;
@@ -1736,7 +1745,7 @@ STATICforIDL CDFstatus ReadAEDRList (vFILE *fp,
       if (!Read32(fp,&(TempAEDR->AEDR.DataType))) return CRE;
       if (!Read32(fp,&(TempAEDR->AEDR.Num))) return CRE;
       if (!Read32(fp,&(TempAEDR->AEDR.NumElems))) return CRE;
-      if (!Read32(fp,&(TempAEDR->AEDR.rfuA))) return CRE;
+      if (!Read32(fp,&(TempAEDR->AEDR.NumStrings))) return CRE;
       if (!Read32(fp,&(TempAEDR->AEDR.rfuB))) return CRE;
       if (!Read32(fp,&(TempAEDR->AEDR.rfuC))) return CRE;
       if (!Read32(fp,&(TempAEDR->AEDR.rfuD))) return CRE;
@@ -1748,9 +1757,9 @@ STATICforIDL CDFstatus ReadAEDRList (vFILE *fp,
       if (TempAEDR->Value == NULL) return BAD_MALLOC;
       if (!READv(TempAEDR->Value,TempAEDR->ValueSize,1,fp)) return CRE;
       if (STRINGdataType(TempAEDR->AEDR.DataType)) {
-        FillSpacesToString((char *)(TempAEDR->Value),
-                           (int)TempAEDR->AEDR.NumElems,
-                           (int)TempAEDR->AEDR.NumElems);
+        FillNulsToString((char *)(TempAEDR->Value),
+                         (int)TempAEDR->AEDR.NumElems,
+                         (int)TempAEDR->AEDR.NumElems);
       }
       ++iEntries;
       if (TempAEDR->AEDR.Num < 0 || TempAEDR->AEDR.Num > MaxEntry)
