@@ -210,8 +210,8 @@ va_dcl
 	 if (!Read64_64(fp,&(CDR->RecordSize))) return CRE;
 	 if (!Read32_64(fp,&(CDR->RecordType))) return CRE;
 	 if (!Read64_64(fp,&(CDR->GDRoffset))) return CRE;
-         /* group read for Version, Release, Encoding, Flags, rfuA, rfuB,
-            Increment, rfuD, rfuE -- all 4-byte big-endian. */
+         /* Group read for Version, Release, Encoding, Flags, rfuA, rfuB,
+            Increment, rfuD, rfuE -- 9 4-byte big-endians. */
          if (!Read32s_64(fp,&(CDR->Version),9)) return CRE;
          /*
   	   if (!Read32_64(fp,&(CDR->Version))) return CRE;
@@ -312,8 +312,8 @@ va_dcl
       if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
       if (!Read64_64(fp,&(fp->GDR64->RecordSize))) return CRE;
       if (!Read32_64(fp,&(fp->GDR64->RecordType))) return CRE;
-      /* group read for rVDRhead, zVDRhead, ADRhead, eof -- all 8-byte
-         big-endian */
+      /* Group read for rVDRhead, zVDRhead, ADRhead, eof -- 4 8-byte
+         big-endians */
       if (!Read64s_64(fp,&(fp->GDR64->rVDRhead),4)) return CRE;
       /*
         if (!Read64_64(fp,&(fp->GDR64->rVDRhead))) return CRE;
@@ -321,8 +321,8 @@ va_dcl
         if (!Read64_64(fp,&(fp->GDR64->ADRhead))) return CRE;
         if (!Read64_64(fp,&(fp->GDR64->eof))) return CRE;
       */
-      /* group read for NrVars, NumAttr, rMaxRec, rNumDims, NzVars -- all
-         4-byte big-endian */
+      /* Group read for NrVars, NumAttr, rMaxRec, rNumDims, NzVars -- 5
+         4-byte big-endians */
       if (!Read32s_64(fp,&(fp->GDR64->NrVars),5)) return CRE;
       /*
         if (!Read32_64(fp,&(fp->GDR64->NrVars))) return CRE;
@@ -332,8 +332,8 @@ va_dcl
         if (!Read32_64(fp,&(fp->GDR64->NzVars))) return CRE;
       */
       if (!Read64_64(fp,&(fp->GDR64->UIRhead))) return CRE;
-      /* group read for rfuC, LeapSecondLastUpdated, rfuE -- all 4-byte
-         big-endian */
+      /* Group read for rfuC, LeapSecondLastUpdated, rfuE -- 3 4-byte
+         big-endians */
       if (!Read32s_64(fp,&(fp->GDR64->rfuC),3)) return CRE;
       /*
         if (!Read32_64(fp,&(fp->GDR64->rfuC))) return CRE;
@@ -364,6 +364,8 @@ va_dcl
 	     if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
 	     if (!Read64_64(fp,&(GDR->RecordSize))) return CRE;
 	     if (!Read32_64(fp,&(GDR->RecordType))) return CRE;
+	     /* Group read for rVDRhead, zVDRhead, ADRhead, eof -- 4 8-byte
+		big-endians. */
              if (!Read64s_64(fp,&(GDR->rVDRhead),4)) return CRE;
              /*
 	       if (!Read64_64(fp,&(GDR->rVDRhead))) return CRE;
@@ -371,6 +373,8 @@ va_dcl
 	       if (!Read64_64(fp,&(GDR->ADRhead))) return CRE;
 	       if (!Read64_64(fp,&(GDR->eof))) return CRE;
              */
+	     /* Group read for NrVars, NumAttr, rMaxRec, rNumDims, NzVars --
+		5 4-byte big-endians. */
              if (!Read32s_64(fp,&(GDR->NrVars),5)) return CRE;
              /*
 	       if (!Read32_64(fp,&(GDR->NrVars))) return CRE;
@@ -380,6 +384,8 @@ va_dcl
 	       if (!Read32_64(fp,&(GDR->NzVars))) return CRE;
              */
 	     if (!Read64_64(fp,&(GDR->UIRhead))) return CRE;
+	     /* Group read for rfuC, LeapSecondLastUpdated, rfuE -- 3 4-byte
+		big-endians. */
              if (!Read32s_64(fp,&(GDR->rfuC),3)) return CRE;
              /*
 	       if (!Read32_64(fp,&(GDR->rfuC))) return CRE;
@@ -668,11 +674,14 @@ va_dcl
 	     if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
              if (!Read64_64(fp,&(ADR->RecordSize))) return CRE;
              if (!Read32_64(fp,&(ADR->RecordType))) return CRE;
+	     /* Group read for ADRnext, AgrEDRhead -- 2 8-byte big-endians. */
              if (!Read64s_64(fp,&(ADR->ADRnext),2)) return CRE;
              /*
                if (!Read64_64(fp,&(ADR->ADRnext))) return CRE;
                if (!Read64_64(fp,&(ADR->AgrEDRhead))) return CRE;
              */
+	     /* Group read for Scope, Num, NgrEntries, MAXgrEntry, rfuA --
+		5 4-byte big-endians. */
              if (!Read32s_64(fp,&(ADR->Scope),5)) return CRE;
              /*
                if (!Read32_64(fp,&(ADR->Scope))) return CRE;
@@ -682,6 +691,8 @@ va_dcl
                if (!Read32_64(fp,&(ADR->rfuA))) return CRE;
              */
              if (!Read64_64(fp,&(ADR->AzEDRhead))) return CRE;
+	     /* Group read for NzEntries, MAXzEntry, rfuE -- 3 4-byte
+		big-endians. */
              if (!Read32s_64(fp,&(ADR->NzEntries),3)) return CRE;
              /*
                if (!Read32_64(fp,&(ADR->NzEntries))) return CRE;
@@ -948,13 +959,15 @@ va_dcl
              if (!Read64_64(fp,&(AEDR->RecordSize))) return CRE;
              if (!Read32_64(fp,&(AEDR->RecordType))) return CRE;
              if (!Read64_64(fp,&(AEDR->AEDRnext))) return CRE;
+	     /* Group read for AttrNum, DataType, Num, NumElems, NumStrings,
+		rfuB, rfuC, rfuD, rfuE -- 9 4-byte big-endians. */
              if (!Read32s_64(fp,&(AEDR->AttrNum),9)) return CRE;
              /*
                if (!Read32_64(fp,&(AEDR->AttrNum))) return CRE;
                if (!Read32_64(fp,&(AEDR->DataType))) return CRE;
                if (!Read32_64(fp,&(AEDR->Num))) return CRE;
                if (!Read32_64(fp,&(AEDR->NumElems))) return CRE;
-               if (!Read32_64(fp,&(AEDR->rfuA))) return CRE;
+               if (!Read32_64(fp,&(AEDR->NumStrings))) return CRE;
                if (!Read32_64(fp,&(AEDR->rfuB))) return CRE;
                if (!Read32_64(fp,&(AEDR->rfuC))) return CRE;
                if (!Read32_64(fp,&(AEDR->rfuD))) return CRE;
@@ -965,8 +978,8 @@ va_dcl
                                   AEDR->NumElems);
                if (!READv64(value,nBytes,1,fp)) return CRE;
                if (STRINGdataType(AEDR->DataType)) {
-                 FillSpacesToString((char *)value, (int)AEDR->NumElems,
-                                    (int)AEDR->NumElems);
+                 FillNulsToString((char *)value, (int)AEDR->NumElems,
+                                  (int)AEDR->NumElems);
                }
              };
          }
@@ -979,7 +992,7 @@ va_dcl
              AEDR->DataType = CurAEDR->AEDR.DataType;
              AEDR->Num = CurAEDR->AEDR.Num;
              AEDR->NumElems = CurAEDR->AEDR.NumElems;
-             AEDR->rfuA = CurAEDR->AEDR.rfuA;
+             AEDR->NumStrings = CurAEDR->AEDR.NumStrings;
              AEDR->rfuB = CurAEDR->AEDR.rfuB;
              AEDR->rfuC = CurAEDR->AEDR.rfuC;
              AEDR->rfuD = CurAEDR->AEDR.rfuD;
@@ -1004,7 +1017,7 @@ va_dcl
 	     nBytes = (size_t) (CDFelemSize(dataType) * numElems);
 	     if (!READv64(value,nBytes,1,fp)) return CRE;
              if (STRINGdataType(dataType)) {
-               FillSpacesToString((char *)value, (int)numElems, (int)numElems);
+               FillNulsToString((char *)value, (int)numElems, (int)numElems);
              }
          }
          else
@@ -1106,6 +1119,17 @@ va_dcl
                }
                break;
            }
+	   case AEDR_NUMSTRINGS: {
+               if (read_only_mode == READONLYoff)
+               {
+                   tOffset += (OFF_T) AEDR_NUMSTRINGS_OFFSET64; break;
+               }
+               else
+               {
+                   *buffer = CurAEDR->AEDR.NumStrings;
+               }
+               break;
+           }
 	   default: return CDF_INTERNAL_ERROR;
 	 }
          if (read_only_mode == READONLYoff)
@@ -1158,16 +1182,20 @@ va_dcl
 	 if (!Read64_64(fp,&(VDR->RecordSize))) return CRE;
 	 if (!Read32_64(fp,&(VDR->RecordType))) return CRE;
 	 if (!Read64_64(fp,&(VDR->VDRnext))) return CRE;
+	 /* Group read for DataType, MaxRec -- 2 4-byte big-endians. */
          if (!Read32s_64(fp,&(VDR->DataType),2)) return CRE;
          /*
 	   if (!Read32_64(fp,&(VDR->DataType))) return CRE;
 	   if (!Read32_64(fp,&(VDR->MaxRec))) return CRE;
          */
+	 /* Group read for VXRhead, VXRtail -- 2 8-byte big-endians. */
          if (!Read64s_64(fp,&(VDR->VXRhead),2)) return CRE;
          /*
 	   if (!Read64_64(fp,&(VDR->VXRhead))) return CRE;
 	   if (!Read64_64(fp,&(VDR->VXRtail))) return CRE;
          */
+	 /* Group read for Flags, sRecords, rfuB, rfuC, rfuF, NumElems,
+	    Num -- 7 4-byte big-endians. */
          if (!Read32s_64(fp,&(VDR->Flags),7)) return CRE;
          /*
 	   if (!Read32_64(fp,&(VDR->Flags))) return CRE;
@@ -1207,8 +1235,8 @@ va_dcl
 	   size_t nBytes = (size_t) (CDFelemSize(VDR->DataType)*VDR->NumElems);
 	   if (!READv64(padValue,nBytes,1,fp)) return CRE;
            if (STRINGdataType(VDR->DataType)) {
-             FillSpacesToString((char *)padValue, (int)VDR->NumElems,
-                                (int)VDR->NumElems);
+             FillNulsToString((char *)padValue, (int)VDR->NumElems,
+                              (int)VDR->NumElems);
            }
 	 }
 	 break;
@@ -1250,8 +1278,7 @@ va_dcl
 	   if (!sX(ReadVDR64(CDF,fp,offset,zVar,
 			    VDR_zNUMDIMS,&nDims,
 			    VDR_NULL),&pStatus)) return pStatus;
-	   tOffset = offset + (OFF_T) (zVDR_DIMVARYS_OFFSETb64 +
-				       (nDims*sizeof(Int32)));
+	   tOffset = offset + (OFF_T) (zVDR_DIMVARYS_OFFSETb64 + nDims*4);
 	 }
 	 else {
 	   OFF_T GDRoffset;
@@ -1282,8 +1309,7 @@ va_dcl
 			     VDR_zNUMDIMS,&zNumDims,
 			     VDR_NULL),&pStatus)) return pStatus;
 	   tOffset = offset + (OFF_T) (zVDR_PADVALUE_OFFSETb64 +
-		     (zNumDims*sizeof(Int32)) +
-		     (zNumDims*sizeof(Int32)));
+		     (zNumDims*4) + (zNumDims*4));
 	 }
 	 else {
 	   Int32 rNumDims;
@@ -1295,14 +1321,14 @@ va_dcl
 			     GDR_rNUMDIMS,&rNumDims,
 			     GDR_NULL),&pStatus)) return pStatus;
 	   tOffset = offset + (OFF_T) (rVDR_PADVALUE_OFFSETb64 +
-		     (rNumDims*sizeof(Int32)));
+		     (rNumDims*4));
 	 }
 	 if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CRE;
 	 nBytes = (size_t) (CDFelemSize(dataType) * numElems);
 	 if (!READv64(padValue,nBytes,1,fp)) return CRE;
          if (STRINGdataType(dataType)) {
-           FillSpacesToString((char *)padValue, (int)numElems,
-                              (int)numElems);
+           FillNulsToString((char *)padValue, (int)numElems,
+                            (int)numElems);
          }
 	 break;
        }
@@ -1313,7 +1339,9 @@ va_dcl
        case VDR_CPRorSPR: {
          OFF_T *buffer = va_arg (ap, OFF_T *); OFF_T tOffset = offset;
          switch (field) {
-           case VDR_RECORDSIZE: tOffset += (OFF_T) VDR_RECORDSIZE_OFFSET64; break; 
+           case VDR_RECORDSIZE:
+             tOffset += (OFF_T) VDR_RECORDSIZE_OFFSET64;
+             break; 
            case VDR_VDRNEXT: tOffset += (OFF_T) VDR_VDRNEXT_OFFSET64; break; 
            case VDR_VXRHEAD: tOffset += (OFF_T) VDR_VXRHEAD_OFFSET64; break; 
 	   case VDR_VXRTAIL: tOffset += (OFF_T) VDR_VXRTAIL_OFFSET64; break;
@@ -1329,7 +1357,9 @@ va_dcl
        default: {
 	 Int32 *buffer = va_arg (ap, Int32 *); OFF_T tOffset = offset;
 	 switch (field) {
-	   case VDR_RECORDTYPE: tOffset += (OFF_T) VDR_RECORDTYPE_OFFSET64; break;
+	   case VDR_RECORDTYPE:
+             tOffset += (OFF_T) VDR_RECORDTYPE_OFFSET64;
+             break;
 	   case VDR_DATATYPE: tOffset += (OFF_T) VDR_DATATYPE_OFFSET64; break;
 	   case VDR_MAXREC: tOffset += (OFF_T) VDR_MAXREC_OFFSET64; break;
 	   case VDR_FLAGS: tOffset += (OFF_T) VDR_FLAGS_OFFSET64; break;
@@ -1385,11 +1415,12 @@ va_dcl
 	 if (!Read64_64(fp,&(VXR->RecordSize))) return CRE;
 	 if (!Read32_64(fp,&(VXR->RecordType))) return CRE;
 	 if (!Read64_64(fp,&(VXR->VXRnext))) return CRE;
-         if (!Read32s_64(fp,&(VXR->Nentries),2)) return CRE;
-         /*
-	   if (!Read32_64(fp,&(VXR->Nentries))) return CRE;
-	   if (!Read32_64(fp,&(VXR->NusedEntries))) return CRE;
-         */
+	 /* Group read for Nentries, NusedEntries -- 2 4-byte big-endians. */
+	 if (!Read32s_64(fp,&(VXR->Nentries),2)) return CRE;
+/*
+	 if (!Read32_64(fp,&(VXR->Nentries))) return CRE;
+	 if (!Read32_64(fp,&(VXR->NusedEntries))) return CRE;
+*/
          if ((int)VXR->Nentries < 0 || (int)VXR->Nentries > MAX_VXR_ENTRIES)
            return CV3C;
 	 if (!Read32s_64(fp,VXR->First,(int)VXR->Nentries)) return CRE;
@@ -1406,7 +1437,7 @@ va_dcl
 			   VXR_NULL),&pStatus)) return pStatus;
 	 switch (field) {
 	   case VXR_FIRSTREC: break;
-	   case VXR_LASTREC: tOffset += (OFF_T) nEntries * sizeof(Int32); break;
+	   case VXR_LASTREC: tOffset += (OFF_T) nEntries * 4; break;
 	   default: return CDF_INTERNAL_ERROR;
 	 }
 	 if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CRE;
@@ -1421,7 +1452,7 @@ va_dcl
          if (!sX(ReadVXR64(fp,offset,
                            VXR_NENTRIES,&nEntries,
                            VXR_NULL),&pStatus)) return pStatus;
-         tOffset += (OFF_T) (2 * nEntries * sizeof(Int32)); 
+         tOffset += (OFF_T) (2 * nEntries * 4); 
          if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CRE;
          if ((int)nEntries < 0 || nEntries > MAX_VXR_ENTRIES)
            return CV3C;
@@ -1432,7 +1463,9 @@ va_dcl
        case VXR_VXRNEXT: {
          OFF_T *buffer = va_arg (ap, OFF_T *); OFF_T tOffset = offset;
          switch (field) {
-           case VXR_RECORDSIZE: tOffset += (OFF_T) VXR_RECORDSIZE_OFFSET64; break; 
+           case VXR_RECORDSIZE:
+             tOffset += (OFF_T) VXR_RECORDSIZE_OFFSET64;
+             break; 
            case VXR_VXRNEXT: tOffset += (OFF_T) VXR_VXRNEXT_OFFSET64; break; 
            default: return CDF_INTERNAL_ERROR;
          }
@@ -1443,9 +1476,13 @@ va_dcl
        default: {
 	 Int32 *buffer = va_arg (ap, Int32 *); OFF_T tOffset = offset;
 	 switch (field) {
-	   case VXR_RECORDTYPE: tOffset += (OFF_T) VXR_RECORDTYPE_OFFSET64; break;
+	   case VXR_RECORDTYPE:
+             tOffset += (OFF_T) VXR_RECORDTYPE_OFFSET64;
+             break;
 	   case VXR_NENTRIES: tOffset += (OFF_T) VXR_NENTRIES_OFFSET64; break;
-	   case VXR_NUSEDENTRIES: tOffset += (OFF_T) VXR_NUSEDENTRIES_OFFSET64; break;
+	   case VXR_NUSEDENTRIES:
+             tOffset += (OFF_T) VXR_NUSEDENTRIES_OFFSET64;
+             break;
 	   default: return CDF_INTERNAL_ERROR;
 	 }
 	 if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CRE;
@@ -1499,7 +1536,9 @@ va_dcl
        default: {
 	 Int32 *buffer = va_arg (ap, Int32 *); OFF_T tOffset = offset;
 	 switch (field) {
-	   case VVR_RECORDTYPE: tOffset += (OFF_T) VVR_RECORDTYPE_OFFSET64; break;
+	   case VVR_RECORDTYPE:
+             tOffset += (OFF_T) VVR_RECORDTYPE_OFFSET64;
+             break;
 	   default: return CDF_INTERNAL_ERROR;
 	 }
 	 if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CRE;
@@ -1558,7 +1597,9 @@ va_dcl
        default: {
 	 OFF_T *buffer = va_arg (ap, OFF_T *); OFF_T tOffset = offset;
 	 switch (field) {
-	   case UIR_RECORDSIZE: tOffset += (OFF_T) UIR_RECORDSIZE_OFFSET64; break;
+	   case UIR_RECORDSIZE:
+             tOffset += (OFF_T) UIR_RECORDSIZE_OFFSET64;
+             break;
 	   case UIR_NEXTUIR: tOffset += (OFF_T) UIR_NEXTUIR_OFFSET64; break;
 	   case UIR_PREVUIR: tOffset += (OFF_T) UIR_PREVUIR_OFFSET64; break;
 	   default: return CDF_INTERNAL_ERROR;
@@ -1614,7 +1655,9 @@ va_dcl
        case CCR_RFUa: {
          Int32 *buffer = va_arg (ap, Int32 *); OFF_T tOffset = offset;
          switch (field) {
-           case CCR_RECORDTYPE: tOffset += (OFF_T) CCR_RECORDTYPE_OFFSET64; break;
+           case CCR_RECORDTYPE:
+             tOffset += (OFF_T) CCR_RECORDTYPE_OFFSET64;
+             break;
            case CCR_RFUa: tOffset += (OFF_T) CCR_RFUa_OFFSET64; break;
            default: return CDF_INTERNAL_ERROR;
          }
@@ -1625,7 +1668,9 @@ va_dcl
        default: {
 	 OFF_T *buffer = va_arg (ap, OFF_T *); OFF_T tOffset = offset;
 	 switch (field) {
-	   case CCR_RECORDSIZE: tOffset += (OFF_T) CCR_RECORDSIZE_OFFSET64; break;
+	   case CCR_RECORDSIZE:
+             tOffset += (OFF_T) CCR_RECORDSIZE_OFFSET64;
+             break;
 	   case CCR_CPROFFSET: tOffset += (OFF_T) CCR_CPROFFSET_OFFSET64; break;
 	   case CCR_USIZE: tOffset += (OFF_T) CCR_USIZE_OFFSET64; break;
 	   default: return CDF_INTERNAL_ERROR;
@@ -1668,6 +1713,8 @@ va_dcl
 	 struct CPRstruct64 *CPR = va_arg (ap, struct CPRstruct64 *); int i;
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
 	 if (!Read64_64(fp,&(CPR->RecordSize))) return CRE;
+	 /* Group read for RecordType, cType, rfuA, pCount -- 4 4-byte
+	    big-endians. */
          if (!Read32s_64(fp,&(CPR->RecordType),4)) return CRE;
          /*
 	   if (!Read32_64(fp,&(CPR->RecordType))) return CRE;
@@ -1691,7 +1738,9 @@ va_dcl
        default: {
 	 Int32 *buffer = va_arg (ap, Int32 *); OFF_T tOffset = offset;
 	 switch (field) {
-	   case CPR_RECORDTYPE: tOffset += (OFF_T) CPR_RECORDTYPE_OFFSET64; break;
+	   case CPR_RECORDTYPE:
+             tOffset += (OFF_T) CPR_RECORDTYPE_OFFSET64;
+             break;
 	   case CPR_CTYPE: tOffset += (OFF_T) CPR_CTYPE_OFFSET64; break;
 	   case CPR_RFUa: tOffset += (OFF_T) CPR_RFUa_OFFSET64; break;
 	   case CPR_PCOUNT: tOffset += (OFF_T) CPR_PCOUNT_OFFSET64; break;
@@ -1740,6 +1789,8 @@ va_dcl
 	 struct SPRstruct64 *SPR = va_arg (ap, struct SPRstruct64 *); int i;
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
 	 if (!Read64_64(fp,&(SPR->RecordSize))) return CRE;
+	 /* Group read for RecordType, sArraysType, rfuA, pCount -- 4 4-byte
+	    big-endians. */
          if (!Read32s_64(fp,&(SPR->RecordType),4)) return CRE;
          /*
 	   if (!Read32_64(fp,&(SPR->RecordType))) return CRE;
@@ -1763,7 +1814,9 @@ va_dcl
        default: {
 	 Int32 *buffer = va_arg (ap, Int32 *); OFF_T tOffset = offset;
 	 switch (field) {
-	   case SPR_RECORDTYPE: tOffset += (OFF_T) SPR_RECORDTYPE_OFFSET64; break;
+	   case SPR_RECORDTYPE:
+             tOffset += (OFF_T) SPR_RECORDTYPE_OFFSET64;
+             break;
 	   case SPR_STYPE: tOffset += (OFF_T) SPR_STYPE_OFFSET64; break;
 	   case SPR_RFUa: tOffset += (OFF_T) SPR_RFUa_OFFSET64; break;
 	   case SPR_PCOUNT: tOffset += (OFF_T) SPR_PCOUNT_OFFSET64; break;
@@ -1812,6 +1865,7 @@ va_dcl
 	 struct CVVRstruct64 *CVVR = va_arg (ap, struct CVVRstruct64 *);
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
 	 if (!Read64_64(fp,&(CVVR->RecordSize))) return CRE;
+	 /* Group read for RecordType, rfuA -- 2 4-byte big-endians. */
          if (!Read32s_64(fp,&(CVVR->RecordType),2)) return CRE;
          /*
 	   if (!Read32_64(fp,&(CVVR->RecordType))) return CRE;
@@ -1824,7 +1878,9 @@ va_dcl
        case CVVR_CSIZE: {
          OFF_T *buffer = va_arg (ap, OFF_T *); OFF_T tOffset = offset;
 	 switch (field) {
-	   case CVVR_RECORDSIZE: tOffset += (OFF_T) CVVR_RECORDSIZE_OFFSET64; break;
+	   case CVVR_RECORDSIZE:
+             tOffset += (OFF_T) CVVR_RECORDSIZE_OFFSET64;
+             break;
 	   case CVVR_CSIZE: tOffset += (OFF_T) CVVR_CSIZE_OFFSET64; break;
 	   default: return CDF_INTERNAL_ERROR;
 	 }
@@ -1835,10 +1891,10 @@ va_dcl
        default: {
 	 Int32 *buffer = va_arg (ap, Int32 *); OFF_T tOffset = offset;
 	 switch (field) {
-           /* case CVVR_RECORDSIZE: tOffset += (OFF_T) CVVR_RECORDSIZE_OFFSET64; break; */
-	   case CVVR_RECORDTYPE: tOffset += (OFF_T) CVVR_RECORDTYPE_OFFSET64; break;
+	   case CVVR_RECORDTYPE:
+             tOffset += (OFF_T) CVVR_RECORDTYPE_OFFSET64;
+             break;
 	   case CVVR_RFUa: tOffset += (OFF_T) CVVR_RFUa_OFFSET64; break;
-           /* case CVVR_CSIZE: tOffset += (OFF_T) CVVR_CSIZE_OFFSET64; break; */
 	   default: return CDF_INTERNAL_ERROR;
 	 }
 	 if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CRE;
@@ -1869,7 +1925,8 @@ STATICforIDL CDFstatus ReadADRList64 (vFILE *fp)
   if (fp->GDR64->NumAttr > 0 && fp->ADRList64 == NULL) return BAD_MALLOC;
   for (i = 0; i < fp->GDR64->NumAttr; i++)
   {
-      fp->ADRList64[i] = cdf_AllocateMemory((size_t)sizeof(struct ADRstruct64), NULL);
+      fp->ADRList64[i] = cdf_AllocateMemory((size_t)sizeof(struct ADRstruct64),
+                                            NULL);
       if (fp->ADRList64[i] == NULL) return BAD_MALLOC;
   };
   /***************************************************************************
@@ -1886,6 +1943,8 @@ STATICforIDL CDFstatus ReadADRList64 (vFILE *fp)
       fp->ADRList64[i]->ADRnext = 0;
       if (!Read64_64(fp,&temp)) return CRE;
       fp->ADRList64[i]->AgrEDRhead = temp;
+      /* Group read for Scope, Num, NgrEntries, MAXgrEntry, rfuA -- 5 4-byte
+	 big-endians. */
       if (!Read32s_64(fp,&(fp->ADRList64[i]->Scope),5)) return CRE;
       /*
       if (!Read32_64(fp,&(fp->ADRList64[i]->Scope))) return CRE;
@@ -1896,6 +1955,7 @@ STATICforIDL CDFstatus ReadADRList64 (vFILE *fp)
       */
       if (!Read64_64(fp,&temp)) return CRE;
       fp->ADRList64[i]->AzEDRhead = temp;
+      /* Group read for NzEntries, MAXzEntry, rfuE -- 3 4-byte big-endians. */
       if (!Read32s_64(fp,&(fp->ADRList64[i]->NzEntries),3)) return CRE;
       /*
         if (!Read32_64(fp,&(fp->ADRList64[i]->NzEntries))) return CRE;
@@ -1967,7 +2027,8 @@ STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp,
   ***************************************************************************/
   while (NxtAEDR != 0 && iEntries != NumEntries)            
   {
-      TempAEDR = cdf_AllocateMemory((size_t)sizeof(struct AEDRstructExt64), NULL);
+      TempAEDR = cdf_AllocateMemory((size_t)sizeof(struct AEDRstructExt64),
+                                    NULL);
       if (TempAEDR == NULL) return BAD_MALLOC;
       if (!SEEKv64(fp,NxtAEDR,vSEEK_SET)) return CRE;
       if (!Read64_64(fp,&temp)) return CRE;
@@ -1976,13 +2037,15 @@ STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp,
       if (!Read64_64(fp,&temp)) return CRE;
       NxtAEDR = temp;
       TempAEDR->AEDR.AEDRnext = 0;
+      /* Group read for AttrNum, DataType, Num, NumElems, NumStrings, rfuB,
+	 rfuC, rfuD, rfuE -- 9 4-byte big-endians. */
       if (!Read32s_64(fp,&(TempAEDR->AEDR.AttrNum),9)) return CRE;
       /*
         if (!Read32_64(fp,&(TempAEDR->AEDR.AttrNum))) return CRE;
         if (!Read32_64(fp,&(TempAEDR->AEDR.DataType))) return CRE;
         if (!Read32_64(fp,&(TempAEDR->AEDR.Num))) return CRE;
         if (!Read32_64(fp,&(TempAEDR->AEDR.NumElems))) return CRE;
-        if (!Read32_64(fp,&(TempAEDR->AEDR.rfuA))) return CRE;
+        if (!Read32_64(fp,&(TempAEDR->AEDR.NumStrings))) return CRE;  
         if (!Read32_64(fp,&(TempAEDR->AEDR.rfuB))) return CRE;
         if (!Read32_64(fp,&(TempAEDR->AEDR.rfuC))) return CRE;
         if (!Read32_64(fp,&(TempAEDR->AEDR.rfuD))) return CRE;
@@ -1997,9 +2060,9 @@ STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp,
       if (TempAEDR->Value == NULL) return BAD_MALLOC;
       if (!READv64(TempAEDR->Value,TempAEDR->ValueSize,1,fp)) return CRE;
       if (STRINGdataType(TempAEDR->AEDR.DataType)) {
-        FillSpacesToString((char *)(TempAEDR->Value),
-                           (int)TempAEDR->AEDR.NumElems,
-                           (int)TempAEDR->AEDR.NumElems);
+        FillNulsToString((char *)(TempAEDR->Value),
+                         (int)TempAEDR->AEDR.NumElems,
+                         (int)TempAEDR->AEDR.NumElems);
       }
       ++iEntries;
       if (TempAEDR->AEDR.Num < 0 || TempAEDR->AEDR.Num > MaxEntry) {
