@@ -768,7 +768,8 @@ switch (Va->item) {
   case ATTR_:
   case ATTR_NAME_: {
     Logical nameOp = (Va->item == ATTR_NAME_);
-    long attrNum; char *attrName; struct CDFstruct *CDF; Int32 offset;
+    long attrNum = -1L; char *attrName = NULL; struct CDFstruct *CDF;
+    Int32 offset;
     if (nameOp)
       attrName = va_arg (Va->ap, char *);
     else {
