@@ -282,8 +282,9 @@ static void LoadLeapSecondsTable ()
     int im, ix;
     table = CDFgetLeapSecondsTableEnvVar();
     if (table != NULL && strlen(table) > 0) {
-      leapTableEnv = (char *) malloc (strlen(table)+1);
-      strcpy (leapTableEnv, table);
+      size_t len = strlen(table);
+      leapTableEnv = (char *) malloc (len + 1);
+      strcpyX (leapTableEnv, table, len);
       leaptable = fopen (table, "r");
       if (leaptable != NULL) {
         int togo = 1;
@@ -299,7 +300,7 @@ static void LoadLeapSecondsTable ()
         ix = 0;
         while (fgets(line, 80, leaptable)) {
           if (line[0] == ';') continue;
-          LTD[ix] = (double *) cdf_AllocateMemory(6 * sizeof(double), NULL);
+          LTD[ix] = (double *) cdf_AllocateMemory(6 * 8, NULL);
           im = sscanf (line, "%ld %ld %ld %lf %lf %lf", &yy, &mm, &dd,
                        &(LTD[ix][3]), &(LTD[ix][4]), &(LTD[ix][5]));
           if (im != 6) {
@@ -329,7 +330,7 @@ static void LoadLeapSecondsTable ()
     if (fromFile == 0) {
       LTD = (double **) cdf_AllocateMemory (NDAT * sizeof (double *), NULL);
       for (ix = 0; ix < NDAT; ++ix) {
-        LTD[ix] = (double *) cdf_AllocateMemory(6 * sizeof(double), NULL);
+        LTD[ix] = (double *) cdf_AllocateMemory(6 * 8, NULL);
         LTD[ix][0] = LTS[ix][0];
         LTD[ix][1] = LTS[ix][1];
         LTD[ix][2] = LTS[ix][2];
@@ -421,9 +422,10 @@ static void RecheckLeapSecondsTableEnvVar ()
   if (table2 != NULL && strlen(table2) > 0) {
     if (leapTableEnv != NULL && table2 != NULL &&
         strcmp (leapTableEnv, table2) != 0) {
+        size_t len = strlen(table2);
         CDFClearLeapSecondsTable();
-        leapTableEnv = (char *) malloc (strlen(table2) + 1);
-        strcpy (leapTableEnv, table2);
+        leapTableEnv = (char *) malloc (len + 1);
+        strcpyX (leapTableEnv, table2, len);
         LoadLeapSecondsTable();
     }
   } else {
@@ -1605,7 +1607,7 @@ VISIBLE_PREFIX long long parseTT2000 (char *string)
   } else if (style == 3 || style == 4) {
     int len; long tmp; char string2[TT2000_0_STRING_LEN+1];
     char ac, tmp2[10], *dot;
-    strcpy (tmp2, "000000000");
+    strcpyX (tmp2, "000000000", 9);
     len = (int) strlen (tmpPtr);
     dot = strrchr (tmpPtr, '.');
     if (dot == NULL) {
@@ -1785,7 +1787,7 @@ static void FromUTCISO8601string (char *string, long *ly, long *lm, long *ld,
     int len; long tmp;
     char ac, tmp2[10], *dot;
     *ly = *lm = *ld = *lh = *ln = *ls = *ll = *lu = *la = 0L;
-    strcpy (tmp2, "000000000");
+    strcpyX (tmp2, "000000000", 9);
     len = (int) strlen (string);
     dot = strrchr (string, '.');
     if (dot == NULL) {
