@@ -174,10 +174,6 @@ STATICforIDL CDFstatus ValidateCDF (struct CDFstruct *CDF, vFILE *CDFfp,
         * Compressed CDF Record (CCR).
         **********************************************************************/
         case CCR_: {
-/*
-          status = ValidateCCR (CDFfp, offset, debug);
-          if (status != CDF_OK) return status;
-*/
           offset = offset + recordSize;
           if (!SEEKv(CDFfp,offset,vSEEK_SET)) return CRE;
 	  break;
@@ -277,10 +273,6 @@ STATICforIDL CDFstatus ValidateCDF (struct CDFstruct *CDF, vFILE *CDFfp,
         * Sparseness Parameters Record (SPR).
         **********************************************************************/
         case SPR_: {
-/*
-          status = ValidateSPR (CDFfp, offset, debug);
-          if (status != CDF_OK) return status;
-*/
           offset = offset + recordSize;
           if (!SEEKv(CDFfp,offset,vSEEK_SET)) return CRE;
 	  break;
@@ -342,9 +334,6 @@ STATICforIDL CDFstatus ValidateCDF (struct CDFstruct *CDF, vFILE *CDFfp,
 static CDFstatus ValidateCDR (vFILE *fp, Int32 offset, Logical debug)
 {
   Int32 actualEncoding;
-/*
-  char copyRight[CDF_COPYRIGHT_LEN+1];
-*/
   CDFstatus status;
  
   if (debug)
@@ -376,12 +365,6 @@ static CDFstatus ValidateCDR (vFILE *fp, Int32 offset, Logical debug)
   if (!ValidEncoding(CDR.Encoding,&actualEncoding)) 
     return QuitCDF ("CDF(CDR): encoding is invalid ", offset,
                     4, 1, &(CDR.Encoding), 0, debug);
-/*
-  for (i = 0; i < strlen(copyRight); ++i) 
-    if (!Printable(copyRight[i])) 
-      return QuitCDF ("CDF(CDR): copyright is invalid ",  offset,
-                      0, copyRight), 0, debug);
-*/
   return CDF_OK;
 }
 
@@ -463,11 +446,6 @@ static CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
   if (ADR.AgrEDRhead < 0 || (ADR.NgrEntries > 0 && ADR.AgrEDRhead == 0)) 
     return QuitCDF ("CDF(ADR): record size is invalid ", offset,
                     4, 1, &(ADR.AgrEDRhead), 0, debug);
-/*
-  if ((ADR.Scope == GLOBAL_SCOPE) && (ADR.NzEntries > 0))
-    return QuitCDF ("CDF(ADR): attribute zEntries exist for a global attribute ", offset,
-                    4, 1, &(ADR.NzEntries), 0, debug);
-*/
   if (!ValidAttrScope(ADR.Scope)) 
     return QuitCDF ("CDF(ADR): scope is invalid ", offset,
                     4, 1, &(ADR.Scope), 0, debug);
@@ -477,33 +455,33 @@ static CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
   if (ADR.NgrEntries < 0) 
     return QuitCDF ("CDF(ADR): number of g/rEntries is invalid ", offset,
                     4, 1, &(ADR.NgrEntries), 0, debug);
-/*
-  if ((ADR.Scope == VARIABLE_SCOPE) && (ADR.NgrEntries > CDF->NrVars)) 
-    return QuitCDF ("CDF(ADR): number of rEntries is invalid ", offset,
-                    4, 1, &(ADR.NgrEntries), 0, debug);
-*/
   if (ADR.MAXgrEntry < -1) 
     return QuitCDF ("CDF(ADR): max g/rEntry is invalid ", offset,
                     4, 1, &(ADR.MAXgrEntry), 0, debug);
+  if ((ADR.Scope == GLOBAL_SCOPE) && (ADR.AzEDRhead > 0))
+    return QuitCDF ("CDF(ADR): global attribute zEntry link is invalid ", offset,
+                    4, 1, &(ADR.AzEDRhead), 0, debug);
+/*
+  if ((ADR.Scope == VARIABLE_SCOPE) && (ADR.MAXgrEntry > -1) &&
+      (GDR.NrVars < 1))
+    return QuitCDF ("CDF(ADR): max rEntry is invalid ", offset,
+                    4, 2, &(ADR.MAXgrEntry), &(GDR.NrVars), debug);
+*/
   if ((ADR.Scope == VARIABLE_SCOPE) && (ADR.MAXgrEntry < (ADR.NgrEntries-1)))
     return QuitCDF ("CDF(ADR): max rEntry is invalid ", offset,
                     4, 2, &(ADR.MAXgrEntry), &(ADR.NgrEntries), debug);
   if (ADR.AzEDRhead < 0 || (ADR.NzEntries > 0 && ADR.AzEDRhead == 0)) 
     return QuitCDF ("CDF(ADR): offset to next AzEDR is invalid ", offset,
                     4, 1, &(ADR.AzEDRhead), 0, debug);
-/*
-  if (ADR.NzEntries < 0 || ((ADR.Scope == VARIABLE_SCOPE) && 
-                            (ADR.NzEntries > CDF->NzVars)))
-    return QuitCDF ("CDF(ADR): number of zEntries is invalid ", offset,
-                    4, 2, &(ADR.NzEntries), &(CDF->NzVars), debug);
-  if (ADR.MAXzEntry < -1 || ((ADR.Scope == VARIABLE_SCOPE) &&
-                             (ADR.MAXzEntry > CDF->NzVars)))
-    return QuitCDF ("CDF(ADR): max zEntry is invalid ", offset,
-                    4, 2, &(ADR.MAXzEntry), &(CDF->NzVars), debug);
-*/
   if ((ADR.Scope == VARIABLE_SCOPE) && (ADR.MAXzEntry < (ADR.NzEntries-1)))
     return QuitCDF ("CDF(ADR): max zEntry is invalid ", offset,
                     4, 2, &(ADR.MAXzEntry), &(ADR.NzEntries), debug);
+/*
+  if ((ADR.Scope == VARIABLE_SCOPE) && (ADR.MAXzEntry > -1) &&
+      (GDR.NzVars < 1))
+    return QuitCDF ("CDF(ADR): max zEntry is invalid ", offset,
+                    4, 2, &(ADR.MAXzEntry), &(GDR.NzVars), debug);
+*/
   if (!ValidAttrName(ADR.Name)) 
     return QuitCDF ("CDF(ADR): attribute name is invalid ",  offset,
                     0, 1, ADR.Name, 0, debug);
@@ -538,14 +516,6 @@ static CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
   if (AEDR.AEDRnext < 0) 
     return QuitCDF ("CDF(AEDR): offset to next AEDR is invalid ", offset,
                     4, 1, &(AEDR.AEDRnext), 0, debug);
-/*  Check for "AEDR.AttrNum != num" is not included as some CDFs fail this
-    check. Don't know why.... */ 
-/*  if (AEDR.AttrNum < 0 || AEDR.AttrNum > GDR.NumAttr || AEDR.AttrNum != num)  */
-/*
-  if (AEDR.AttrNum < 0 || AEDR.AttrNum > GDR.NumAttr) 
-    return QuitCDF ("CDF(AEDR): attribute number is invalid ", offset,
-                    4, 2, &(AEDR.AttrNum), &(GDR.NumAttr), debug);
-*/
   if (!ValidDataType(AEDR.DataType) || InValidDataType(AEDR.DataType))
     return QuitCDF ("CDF(AEDR): data type is invalid ", offset,
                     4, 1, &(AEDR.DataType), 0, debug);
@@ -555,11 +525,6 @@ static CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
   if (AEDR.AEDRnext < 0)
     return QuitCDF ("CDF(AEDR): next AEDR offset is invalid : ", offset,
                     4, 1, &(AEDR.AEDRnext), 0, debug);
-/*  
-  if (zEntry && AEDR.EntryNum > GDR->NzVars)
-    return QuitCDF ("CDF(AEDR): entry number is invalid ", offset,
-                    4, 2, &(AEDR.Num), &(GDR->NzVars), debug);
-*/
   if (AEDR.NumElems < 1 || 
       (STRINGdataType(AEDR.DataType) && 
        AEDR.NumElems > (AEDR.RecordSize - AEDR_VALUE_OFFSET))) 
@@ -685,7 +650,7 @@ static CDFstatus ValidateVXR (vFILE *fp, Int32 offset, Int32 lastRec,
     status = ValidateVXR (fp, VXR.VXRnext, lastRec, debug); 
     if (status != CDF_OK) return status;
   } else if (VXR.VXRnext < 0) {
-      return QuitCDF ("CDF(VXR): a link offset to next rec is negative in a VIR: ",
+      return QuitCDF ("CDF(VXR): a link offset to next rec is negative in a VXR: ",
                       offset, 4, 1, &(VXR.VXRnext), 0, debug);
   }
 
@@ -730,8 +695,7 @@ static CDFstatus ValidateVVR (vFILE *fp, Int32 offset, Logical debug)
                     4, 1, &(VVR.RecordType), 0, debug);
   if (VVR.RecordSize < VVR_BASE_SIZE) 
     return QuitCDF ("CDF(VVR): record size is invalid for Variable Value Record",
-                        offset,
-                    4, 1, &(VVR.RecordSize), 0, debug);
+                    offset, 4, 1, &(VVR.RecordSize), 0, debug);
   return CDF_OK;
 }
 
@@ -754,17 +718,16 @@ static CDFstatus ValidateUIR (vFILE *fp, Int32 offset, Logical debug)
     return QuitCDF ("CDF(UIR): record type is invalid ", offset,
                     4, 1, &(UIR.RecordType), 0, debug);
   if (UIR.RecordSize < UIR_BASE_SIZE) 
-    return QuitCDF ("CDF(UIR): record size is invalid for Unused Internal Record",
+    return QuitCDF ("CDF(UIR): record size is invalid for UIR",
                         offset,
                     4, 1, &(UIR.RecordSize), 0, debug);
   if (UIR.NextUIR < 0) 
-    return QuitCDF ("CDF(UIR): offset to next UIR is invalid for Unused Internal Record",
+    return QuitCDF ("CDF(UIR): offset to next UIR is invalid for UIR",
                         offset,
                     4, 1, &(UIR.NextUIR), 0, debug);
   if (UIR.PrevUIR < 0) 
-    return QuitCDF ("CDF(UIR): offset to previous UIR is invalid for Unused Internal Record",
-                        offset,
-                    4, 1, &(UIR.PrevUIR), 0, debug);
+    return QuitCDF ("CDF(UIR): offset to previous UIR is invalid for UIR",
+                    offset, 4, 1, &(UIR.PrevUIR), 0, debug);
   return CDF_OK;
 }
 
@@ -817,7 +780,7 @@ static CDFstatus ValidateCPR (vFILE *fp, Int32 offset, Logical debug)
   if (CPR.RecordType != CPR_)
     return QuitCDF ("CDF(CPR): record type is invalid ", offset,
                     4, 1, &(CPR.RecordType), 0, debug);
-  if (CPR.RecordSize != (CPR_BASE_SIZE + CPR.pCount * sizeof(Int32)))
+  if (CPR.RecordSize != (CPR_BASE_SIZE + CPR.pCount * 4))
     return QuitCDF ("CDF(CPR): reocrd size is invalid ", offset,
                     4, 1, &(CPR.RecordSize), 0, debug);
   if (CPR.pCount != 1) 
@@ -849,7 +812,7 @@ static CDFstatus ValidateSPR (vFILE *fp, Int32 offset, Logical debug)
   if (SPR.RecordType != SPR_)
     return QuitCDF ("CDF(SPR): record type is invalid ", offset,
                     4, 1, &(SPR.RecordType), 0, debug);
-  if (SPR.RecordSize != (SPR_BASE_SIZE + SPR.pCount * sizeof(Int32)))
+  if (SPR.RecordSize != (SPR_BASE_SIZE + SPR.pCount * 4))
     return QuitCDF ("CDF(SPR): record size is invalid ", offset,
                     4, 1, &(SPR.RecordSize), 0, debug);
   if (SPR.pCount < 1 || SPR.pCount > CDF_MAX_PARMS) 
@@ -894,7 +857,7 @@ static CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp,
   Int32 num, numgrEntries, maxgrEntry, numzEntries, maxzEntry;
   int ix, *visit;
 
-  visit = (int *) cdf_AllocateMemory(GDR.NumAttr * sizeof(Int32), NULL);
+  visit = (int *) cdf_AllocateMemory(GDR.NumAttr * 4, NULL);
   for (ix = 0; ix < GDR.NumAttr; ++ix) visit[ix] = 0;
   offset = GDR.ADRhead;
   for (ix = 0; ix < GDR.NumAttr; ++ix) {
@@ -947,9 +910,9 @@ static CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp,
 ******************************************************************************/
 
 static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp, 
-                                      Int32 num, Logical zEntry, Int32 EDRhead, 
-                                             Int32 numEntries, Int32 maxEntry,
-                                             Logical debug)
+                                             Int32 num, Logical zEntry,
+                                             Int32 EDRhead, Int32 numEntries,
+                                             Int32 maxEntry, Logical debug)
 {
   CDFstatus status;
   Int32 offset, nextAEDR;
@@ -958,8 +921,7 @@ static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
 
   offset = EDRhead;
   lastNum = 0;
-  visits = (Int32 *) cdf_AllocateMemory ((size_t)numEntries * sizeof(Int32),
-                        NULL);
+  visits = (Int32 *) cdf_AllocateMemory ((size_t)numEntries * 4, NULL);
   if (visits == NULL) return BAD_MALLOC;
   for (ix = 0; ix < numEntries; ++ix) visits[ix] = 0;
   ix = 0;
@@ -1014,7 +976,7 @@ static CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
   int ix, numVars, *visit;
 
   numVars = (zVar ? GDR.NzVars : GDR.NrVars);
-  visit = (int *) cdf_AllocateMemory ((size_t)numVars * sizeof(Int32), NULL);
+  visit = (int *) cdf_AllocateMemory ((size_t)numVars * 4, NULL);
   if (visit == NULL) return BAD_MALLOC;
   for (ix = 0; ix < numVars; ++ix) visit[ix] = 0;
   offset = (zVar ? GDR.zVDRhead : GDR.rVDRhead);
@@ -1040,15 +1002,6 @@ static CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
         return status;
       }
     }
-/*
-    if (CDF->singleFile && (headVXR != tailVXR) && tailVXR > 0) {
-      status = ValidateVariableValueLinks (CDF, fp, lastRec, tailVXR, debug);
-      if (status != CDF_OK) {
-        cdf_FreeMemory (visit, NULL);
-        return status;
-      }
-    }
-*/
     if (VARcompressionBITset(flags)) {
       status = ValidateCPR (fp, cprOffset, debug);
       if (status != CDF_OK) {
