@@ -107,7 +107,7 @@ vFILE *fp;
 Int32 offset;
 Int32 *irType;
 {
-  long irTypeOffset = offset + sizeof(Int32);
+  long irTypeOffset = offset + 4;
   if (!SEEKv(fp,irTypeOffset,vSEEK_SET)) return CWE;
   if (!Write32(fp,irType)) return CWE;
   return CDF_OK;
@@ -389,7 +389,7 @@ va_dcl
 	 if (!Write32(fp,&(AEDR->DataType))) return CWE;
 	 if (!Write32(fp,&(AEDR->Num))) return CWE;
 	 if (!Write32(fp,&(AEDR->NumElems))) return CWE;
-	 if (!Write32(fp,&(AEDR->rfuA))) return CWE;
+	 if (!Write32(fp,&(AEDR->NumStrings))) return CWE;
 	 if (!Write32(fp,&(AEDR->rfuB))) return CWE;
 	 if (!Write32(fp,&(AEDR->rfuC))) return CWE;
 	 if (!Write32(fp,&(AEDR->rfuD))) return CWE;
@@ -404,7 +404,7 @@ va_dcl
 						       NULL);
 	       memcpy (newValue, (char *)value, len);
 	       for (ix = (int) len; ix < (int) AEDR->NumElems; ++ix)
-	         *(newValue+ix) = (char) ' ';
+	         *(newValue+ix) = (char) '\0';
 	     }
 	     if (!sX(WriteBuffer(CDF,fp,AEDR->DataType,AEDR->NumElems,
 				 (newValue==NULL?value:(void *)newValue)),
@@ -434,7 +434,7 @@ va_dcl
 	     newValue = (char *) cdf_AllocateMemory ((size_t) numElems, NULL);
 	     memcpy (newValue, (char *)value, len);
 	     for (ix = (int) len; ix < (int) numElems; ++ix)
-	        *(newValue+ix) = (char) ' ';
+	        *(newValue+ix) = (char) '\0';
 	   }
 	   if (!sX(WriteBuffer(CDF,fp,dataType,numElems,
 			       (newValue==NULL?value:(void *)newValue)),
@@ -456,6 +456,7 @@ va_dcl
 	   case AEDR_DATATYPE: tOffset += AEDR_DATATYPE_OFFSET; break;
 	   case AEDR_NUM: tOffset += AEDR_NUM_OFFSET; break;
 	   case AEDR_NUMELEMS: tOffset += AEDR_NUMELEMS_OFFSET; break;
+	   case AEDR_NUMSTRINGS: tOffset += AEDR_NUMSTRINGS_OFFSET; break;
 	   default: return CDF_INTERNAL_ERROR;
 	 }
 	 if (!SEEKv(fp,tOffset,vSEEK_SET)) return CWE;
@@ -547,7 +548,7 @@ va_dcl
 						     NULL);
 	       memcpy (newPad, (char *)padValue, len);
 	       for (ix = (int) len; ix < (int) VDR->NumElems; ++ix)
-		 *(newPad+ix) = (char) ' ';
+		 *(newPad+ix) = (char) '\0';
 	     }
 	     if (!sX(WriteBuffer(CDF,fp,VDR->DataType,VDR->NumElems,
 				 (newPad==NULL?padValue:(void *)newPad)),
@@ -596,7 +597,7 @@ va_dcl
 	   if (!sX(ReadVDR(CDF,fp,offset,zVar,
 			   VDR_zNUMDIMS,&nDims,
 			   VDR_NULL),&pStatus)) return pStatus;
-	   tOffset = offset + zVDR_DIMVARYS_OFFSETb + (nDims * sizeof(Int32));
+	   tOffset = offset + zVDR_DIMVARYS_OFFSETb + (nDims * 4);
 	 }
 	 else {
 	   Int32 GDRoffset;
@@ -625,7 +626,7 @@ va_dcl
 			   VDR_zNUMDIMS,&zNumDims,
 			   VDR_NULL),&pStatus)) return pStatus;
 	   tOffset = offset + zVDR_PADVALUE_OFFSETb +
-		     (zNumDims * sizeof(Int32)) + (zNumDims * sizeof(Int32));
+		     (zNumDims * 4) + (zNumDims * 4);
 	 }
 	 else {
 	   Int32 rNumDims, GDRoffset;
@@ -635,7 +636,7 @@ va_dcl
 	   if (!sX(ReadGDR(fp,GDRoffset,
 			   GDR_rNUMDIMS,&rNumDims,
 			   GDR_NULL),&pStatus)) return pStatus;
-	   tOffset = offset + rVDR_PADVALUE_OFFSETb + (rNumDims*sizeof(Int32));
+	   tOffset = offset + rVDR_PADVALUE_OFFSETb + (rNumDims*4);
 	 }
 	 if (!SEEKv(fp,tOffset,vSEEK_SET)) return CWE;
 	 if (STRINGdataType(dataType)) {
@@ -646,7 +647,7 @@ va_dcl
 	     newPad = (char *) cdf_AllocateMemory ((size_t) numElems, NULL);
 	     memcpy (newPad, (char *)padValue, len);
 	     for (ix = (int) len; ix < (int) numElems; ++ix)
-	        *(newPad+ix) = (char) ' ';
+	        *(newPad+ix) = (char) '\0';
 	   }
 	   if (!sX(WriteBuffer(CDF,fp,dataType,numElems,
 			       (newPad==NULL?padValue:(void *)newPad)),
@@ -733,8 +734,8 @@ va_dcl
 			 VXR_NULL),&pStatus)) return pStatus;
 	 switch (field) {
 	   case VXR_FIRSTREC: break;
-	   case VXR_LASTREC: tOffset += nEntries * sizeof(Int32); break;
-	   case VXR_OFFSET: tOffset += 2 * nEntries * sizeof(Int32); break;
+	   case VXR_LASTREC: tOffset += nEntries * 4; break;
+	   case VXR_OFFSET: tOffset += 2 * nEntries * 4; break;
 	   default: return CDF_INTERNAL_ERROR;
 	 }
 	 if (!SEEKv(fp,tOffset,vSEEK_SET)) return CWE;
