@@ -49,6 +49,8 @@
 *   V2.9  10-Dec-10, M Liu      Added encodeEPOCH4, encodeEPOCH16_4,
 *                               parseEPOCH4, parseEPOCH16_4 to handle epochs
 *                               conforming to ISO 8601.
+*   V2.10 10-Sep-18, M Liu      Added toEncodeEPOCH, toEncodeEPOCH16 functions.
+*                               Added toParseEPOCH, toParseEPOCH16 functions.
 ******************************************************************************/
 
 #include "cdflib.h"
@@ -61,6 +63,9 @@
 #define MAX_MOD_LEN		10
 #define MAX_ePART_LEN		25
 
+/*static double BeginUnixTimeEPOCH = 62167219200000.0;*/
+/*static double BeginUnixTimeEPOCH16 = 62167219200.0;*/
+
 /******************************************************************************
 * Local function prototypes.
 ******************************************************************************/
@@ -96,6 +101,95 @@ static double computeEpoch16 PROTOARGs((
   long msec, long usec, long nsec, long psec, double epoch[]
 ));
 
+/******************************************************************************
+* toParseEPOCH.
+* This function parses an input date/time string and returns an EPOCH
+* value.  The string format must be exactly as one of the followings shown
+* below:
+*
+* Style: 0       dd-mmm-yyyy hh:mm:ss.mmm (len = 24)
+* Examples:       1-Apr-1990 03:05:02.000
+*                10-Oct-1993 23:45:49.999
+*
+* Style: 1       yyyymmdd.ttttttt (len = 16)
+* Examples:      19950508.0000000
+*                19671231.58      (== 19671213.5800000)
+*
+* Style: 2       yyyymmddhhmmss (len = 14)
+* Examples:      19950508000000
+*                19671231235959
+*
+* Style: 3       yyyy-mm-ddThh:mm:ss.cccZ (len = 24)
+* Examples:      1990-04-01T03:05:02.000Z
+*                1993-10-10T23:45:49.999Z
+*
+* Style: 4       yyyy-mm-ddThh:mm:ss.ccc (len = 23)
+* Examples:      1990-04-01T03:05:02.000
+*                1993-10-10T23:45:49.999
+*
+* If a 'Nan' string is detected, then Nan is returned. A Nan epoch value 
+* can only be handled by toEncodeEPOCH.
+******************************************************************************/
+
+VISIBLE_PREFIX double toParseEPOCH (inString)
+char *inString;
+{
+  int len; long tmp; char *tmpPtr, *end; double epoch; int is, ie;
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     return NAN;
+#else
+     int zero = 0;
+     return (0.0 / zero);
+#endif
+  }
+  is = ie = 0;
+  len = (int) strlen(inString);
+  while(isspace((unsigned char)*(inString+is)) ||
+        !isprint((unsigned char)*(inString+is))) is++;
+  while(isspace((unsigned char)*(inString+len-ie-1)) ||
+        !isprint((unsigned char)*(inString+len-ie-1))) ie++;
+  len = len - is - ie;
+  tmpPtr = (char *) malloc ((size_t)len+1);
+  memcpy (tmpPtr, inString+is, (size_t)len);
+  *(tmpPtr+len) = (char) '\0';
+  if (len == EPOCH_STRING_LEN) {
+    /* Style 0 or 3 */
+    if (tmpPtr[11] == ' ') {
+      epoch = parseEPOCH (tmpPtr);
+    } else if (tmpPtr[10] == 'T' || tmpPtr[10] == 't' ||
+               tmpPtr[10] == ' ' || tmpPtr[10] == '/') {
+      epoch = parseEPOCH3 (tmpPtr);
+    } else {
+      epoch = ILLEGAL_EPOCH_VALUE;
+    }
+  } else if (len == EPOCH1_STRING_LEN && tmpPtr[8] == '.') {
+     epoch = parseEPOCH1 (tmpPtr);
+  } else if (len == EPOCH2_STRING_LEN && sscanf(tmpPtr, "%8ld", &tmp) == 1) {
+     epoch = parseEPOCH2 (tmpPtr);
+  } else if (len == EPOCH4_STRING_LEN && (tmpPtr[10] == 'T' ||
+                                          tmpPtr[10] == 't' || 
+                                          tmpPtr[10] == '/' || 
+                                          tmpPtr[10] == ' ')) {
+     epoch = parseEPOCH4 (tmpPtr);
+  } else if (len == (EPOCH_STRING_LEN+1) && (tmpPtr[len-1] == 'Z' ||
+                                           tmpPtr[len-1] == 'z')) {
+     epoch = parseEPOCH (tmpPtr);
+  } else if (tmpPtr[11] == ' ') {
+     epoch = parseEPOCH (tmpPtr);
+  } else if (tmpPtr[10] == 'T' || tmpPtr[10] == 't' ||
+           tmpPtr[10] == '/' || tmpPtr[10] == ' ') {
+     if (tmpPtr[len-1] == 'Z' || tmpPtr[len-1] == 'z')
+       epoch = parseEPOCH3 (tmpPtr);
+     else
+       epoch = parseEPOCH4 (tmpPtr);
+  } else {
+     epoch = ILLEGAL_EPOCH_VALUE;
+  }
+  free (tmpPtr);
+  return epoch;
+}
+
 /******************************************************************************
 * parseEPOCH.
 * This function parses an input date/time string and returns an EPOCH
@@ -107,6 +201,7 @@ static double computeEpoch16 PROTOARGs((
 *               10-Oct-1993 23:45:49.999
 *
 * The expected format is the same as that produced by encodeEPOCH.
+* If an "Nan" string is detected, then a value of NAN is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX double parseEPOCH (inString)
@@ -115,9 +210,18 @@ char *inString;
   char moString[4];
   long year, month, day, hour, minute, second, msec;
   int monthX;
-  if (sscanf(inString,"%ld-%c%c%c-%ld %ld:%ld:%ld.%ld",
+  msec = 0L;
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     return NAN;
+#else
+     int zero = 0;
+     return (0.0 / zero);
+#endif
+  }
+  if (sscanf(inString,"%2ld-%c%c%c-%4ld %2ld:%2ld:%2ld.%3ld",
              &day, &(moString[0]), &(moString[1]), &(moString[2]), &year,
-             &hour, &minute, &second, &msec) != 9) return ILLEGAL_EPOCH_VALUE; 
+             &hour, &minute, &second, &msec) < 8) return -1.0E31; 
   moString[0] = (char) MakeUpper((int)moString[0]);   /* J */
   moString[1] = (char) MakeLower((int)moString[1]);   /* a */
   moString[2] = (char) MakeLower((int)moString[2]);   /* n */
@@ -132,6 +236,118 @@ char *inString;
   return computeEPOCH (year, month, day, hour, minute, second, msec);
 }  
 
+/******************************************************************************
+* toParseEPOCH16.
+* This function parses an input date/time string and returns an EPOCH16
+* value.  The string format must be exactly as one of the followings shown
+* elow.
+*
+* Style: 0       dd-mmm-yyyy hh:mm:ss.mmm.uuu.nnn.ppp (len = 36)
+* Examples:       1-Apr-1990 03:05:02.000.000.000.000
+*                10-Oct-1993 23:45:49.999.999.999.999
+*
+* Style: 1       yyyymmdd.ttttttttttttttt (len = 24)
+* Examples:      19950508.000000000000000
+*                19671231.58      (== 19671213.580000000000000)
+*
+* Style: 2       yyyymmddhhmmss (len = 14)
+* Examples:      19950508000000
+*                19671231235959
+*
+* Style: 3       yyyy-mm-ddThh:mm:ss.ccc.uuu.nnn.pppZ (len = 36)
+* Examples:      1990-04-01T03:05:02.000.000.000.000Z
+*                1993-10-10T23:45:49.999.999.999.999Z
+*
+* Style: 4       yyyy-mm-ddThh:mm:ss.cccuuunnnppp (len = 32)
+* Examples:      1990-04-01T03:05:02.000000000000
+*                1993-10-10T23:45:49.999999999999
+*
+******************************************************************************/
+
+VISIBLE_PREFIX double toParseEPOCH16 (inString, epoch16)
+char *inString;
+double epoch16[2];
+{
+  int len; long tmp; char *tmpPtr, *end; double dummy; int is, ie;
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     epoch16[0] = epoch16[1] = NAN;
+     return 0.0;
+#else
+     int zero = 0;
+     epoch16[0] = 0.0 / zero;
+     epoch16[1] = 0.0 / zero;
+     return 0.0;
+#endif
+  }
+  is = ie = 0;
+  len = (int) strlen(inString);
+  while(isspace((unsigned char)*(inString+is)) ||
+        !isprint((unsigned char)*(inString+is))) is++;
+  while(isspace((unsigned char)*(inString+len-ie-1)) ||
+        !isprint((unsigned char)*(inString+len-ie-1))) ie++;
+  len = len - is - ie;
+  tmpPtr = (char *) malloc ((size_t)len+1);
+  memcpy (tmpPtr, inString+is, (size_t)len);
+  *(tmpPtr+len) = (char) '\0';
+  if (len == EPOCH16_STRING_LEN) {
+    /* Style 0 or 3 */
+    if (tmpPtr[11] == ' ') {
+      dummy = parseEPOCH16 (tmpPtr, epoch16);
+    } else if (tmpPtr[10] == 'T' || tmpPtr[10] == 't' || tmpPtr[10] == ' '
+             || tmpPtr[10] == '/') {
+       dummy = parseEPOCH16_3 (tmpPtr, epoch16);
+    } else {
+      epoch16[0] = epoch16[1] = -1.0E31;
+      dummy = ILLEGAL_EPOCH_VALUE;
+    }
+  } else if (len == EPOCH16_1_STRING_LEN &&
+             tmpPtr[8] == '.') {
+     dummy = parseEPOCH16_1 (tmpPtr, epoch16);
+  } else if (len == EPOCH16_2_STRING_LEN && 
+           sscanf(tmpPtr, "%8ld", &tmp) == 1) {
+     dummy = parseEPOCH16_2 (tmpPtr, epoch16);
+  } else if (len == EPOCH16_4_STRING_LEN && 
+           (tmpPtr[10] == 'T' || tmpPtr[10] == 't' || tmpPtr[10] == ' ')) {
+     dummy = parseEPOCH16_4 (tmpPtr, epoch16);
+  } else if (len < EPOCH16_STRING_LEN && tmpPtr[11] == ' ') {
+     dummy = parseEPOCH16 (tmpPtr, epoch16);
+  } else if (len < EPOCH16_STRING_LEN && (tmpPtr[10] == 'T' ||
+                                        tmpPtr[10] == 't' ||
+                                        tmpPtr[10] == '/' ||
+                                        tmpPtr[10] == ' ')) {
+    if (tmpPtr[len-1] == 'Z' || tmpPtr[len-1] == 'z') {
+      char *tmpx = (char *) malloc (len);
+      strncpy (tmpx, tmpPtr, (size_t)len-1);
+      *(tmpx+(len-1)) = '\0';
+      dummy = parseEPOCH16_4 (tmpx, epoch16);
+      free (tmpx);
+    } else {
+      if (len == (EPOCH16_3_STRING_LEN - 1))
+        dummy = parseEPOCH16_3 (tmpPtr, epoch16);
+      else
+        dummy = parseEPOCH16_4 (tmpPtr, epoch16);
+    }
+  } else if (len == (EPOCH16_STRING_LEN + 1) && tmpPtr[11] == ' ' &&
+           (tmpPtr[EPOCH16_STRING_LEN] == 'Z' ||
+            tmpPtr[EPOCH16_STRING_LEN] == 'z')) {
+      dummy = parseEPOCH16 (tmpPtr, epoch16);
+  } else if (tmpPtr[11] == ' ') {
+      dummy = parseEPOCH16 (tmpPtr, epoch16);
+  } else if (tmpPtr[10] == 'T' || tmpPtr[10] == 't' ||
+           tmpPtr[10] == '/' || tmpPtr[10] == ' ') {
+         if (tmpPtr[len-1] == 'Z' || tmpPtr[len-1] == 'z') 
+           dummy = parseEPOCH16_3 (tmpPtr, epoch16);
+         else
+           dummy = parseEPOCH16_4 (tmpPtr, epoch16);
+  } else {
+    epoch16[0] = epoch16[1] = -1.0E31;
+    dummy = ILLEGAL_EPOCH_VALUE;
+  }
+  free (tmpPtr);
+  return dummy;
+}
+
 /******************************************************************************
 * parseEPOCH16.
 * This function is an extension of parseEPOCH. It is used to handle the time
@@ -143,6 +359,7 @@ char *inString;
 *		10-Oct-1993 23:45:49.999.999.999.999
 *
 * The expected format is the same as that produced by encodeEPOCH16.
+* If an Nan value is detected, then a string of "Nan" is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX double parseEPOCH16 (inString, epoch)
@@ -153,9 +370,21 @@ double epoch[2];
   long year, month, day, hour, minute, second, msec, usec, nsec, psec;
   double mmm;
   int monthX;
-  if (sscanf(inString,"%ld-%c%c%c-%ld %ld:%ld:%ld.%ld.%ld.%ld.%ld",
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     epoch[0] = epoch[1] = NAN;
+     return 0.0;
+#else
+     int zero = 0;
+     epoch[0] = 0.0 / zero;
+     epoch[1] = 0.0 / zero;
+     return 0.0;
+#endif
+  }
+  msec = usec = nsec = psec = 0L;
+  if (sscanf(inString,"%2ld-%c%c%c-%4ld %2ld:%2ld:%2ld.%3ld.%3ld.%3ld.%3ld",
 	     &day, &(moString[0]), &(moString[1]), &(moString[2]), &year,
-	     &hour, &minute, &second, &msec, &usec, &nsec, &psec) != 12) 
+	     &hour, &minute, &second, &msec, &usec, &nsec, &psec) < 8) 
         return ILLEGAL_EPOCH_VALUE;
   moString[0] = (char) MakeUpper((int)moString[0]);   /* J */
   moString[1] = (char) MakeLower((int)moString[1]);   /* a */
@@ -198,6 +427,7 @@ double epoch[2];
 *		19671231.58      (== 19671213.5800000)
 *
 * The expected format is the same as that produced by encodeEPOCH1.
+* If an "Nan" string is detected, then a value of NAN is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX double parseEPOCH1 (inString)
@@ -205,6 +435,14 @@ char *inString;
 {
   char temp[EPOCH1_STRING_LEN+1]; double fraction; int i;
   long year, month, day, hour, minute, second, msec, fractionL;
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     return NAN;
+#else
+     int zero = 0;
+     return (0.0 / zero);
+#endif
+  }
   strcpyX (temp, inString, EPOCH1_STRING_LEN);
   for (i = strlen(temp); i < EPOCH1_STRING_LEN; i++) temp[i] = '0';
   temp[i] = NUL;
@@ -233,6 +471,7 @@ char *inString;
 *               19671231.58      (== 19671213.580000000000000)
 *
 * The expected format is the same as that produced by encodeEPOCH16_1.
+* If an "Nan" string is detected, then a value of NAN is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX double parseEPOCH16_1 (inString, epoch)
@@ -243,6 +482,17 @@ double epoch[2];
   long year, month, day, hour, minute, second, fractionL1, fractionL2;
   double mmm;
 
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     epoch[0] = epoch[1] = NAN;
+     return 0.0;
+#else
+     int zero = 0;
+     epoch[0] = 0.0 / zero;
+     epoch[1] = 0.0 / zero;
+     return 0.0;
+#endif
+  }
   if (!strcmp (inString, "99991231.999999999999999")) {
     epoch[0] = -1.0E31;
     epoch[1] = -1.0E31;
@@ -280,12 +530,21 @@ double epoch[2];
 *		19671231235959
 *
 * The expected format is the same as that produced by encodeEPOCH2.
+* If an "Nan" string is detected, then a value of NAN is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX double parseEPOCH2 (inString)
 char *inString;
 {
   long year, month, day, hour, minute, second;
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     return NAN;
+#else
+     int zero = 0;
+     return (0.0 / zero);
+#endif
+  }
   if (sscanf(inString,"%4ld%2ld%2ld%2ld%2ld%2ld",
 	     &year,&month,&day,&hour,&minute,&second) != 6) {
     return ILLEGAL_EPOCH_VALUE;
@@ -303,6 +562,7 @@ char *inString;
 *               19671231235959
 *
 * The expected format is the same as that produced by encodeEPOCH16_2.
+* If an "Nan" string is detected, then a value of NAN is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX double parseEPOCH16_2 (inString, epoch)
@@ -311,6 +571,17 @@ double epoch[2];
 {
   long year, month, day, hour, minute, second;
   double mmm;
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     epoch[0] = epoch[1] = NAN;
+     return 0.0;
+#else
+     int zero = 0;
+     epoch[0] = 0.0 / zero;
+     epoch[1] = 0.0 / zero;
+     return 0.0;
+#endif
+  }
   if (sscanf(inString,"%4ld%2ld%2ld%2ld%2ld%2ld",
              &year,&month,&day,&hour,&minute,&second) != 6) {
     return ILLEGAL_EPOCH_VALUE;
@@ -332,14 +603,25 @@ double epoch[2];
 *		1993-10-10T23:45:49.999Z
 *
 * The expected format is the same as that produced by encodeEPOCH3.
+* If an "Nan" string is detected, then a value of NAN is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX double parseEPOCH3 (inString)
 char *inString;
 {
   long year, month, day, hour, minute, second, msec;
-  if (sscanf(inString,"%ld-%ld-%ldT%ld:%ld:%ld.%ldZ",
-	     &year,&month,&day,&hour,&minute,&second,&msec) != 7) {
+  char T, Z;
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     return NAN;
+#else
+     int zero = 0;
+     return (0.0 / zero);
+#endif
+  }
+  msec = 0L;
+  if (sscanf(inString,"%4ld-%2ld-%2ld%c%2ld:%2ld:%2ld.%3ld%c",
+	     &year,&month,&day,&T,&hour,&minute,&second,&msec,&Z) < 7) {
     return ILLEGAL_EPOCH_VALUE;
   }
   return computeEPOCH (year, month, day, hour, minute, second, msec);
@@ -355,6 +637,7 @@ char *inString;
 *               1993-10-10T23:45:49.999.999.999.999Z
 *
 * The expected format is the same as that produced by encodeEPOCH16_3.
+* If an "Nan" string is detected, then a value of NAN is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX double parseEPOCH16_3 (inString, epoch)
@@ -362,13 +645,24 @@ char *inString;
 double epoch[2];
 {
   long year, month, day, hour, minute, second, msec, usec, nsec, psec;
-  int len;
+  int len; char T, Z;
   double mmm;
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     epoch[0] = epoch[1] = NAN;
+     return 0.0;
+#else
+     int zero = 0;
+     epoch[0] = 0.0 / zero;
+     epoch[1] = 0.0 / zero;
+     return 0.0;
+#endif
+  }
+  msec = usec = nsec = psec = 0L;
   len = strlen(inString);
-  if (len < EPOCH16_3_STRING_LEN) return ILLEGAL_EPOCH_VALUE;
-  if (sscanf(inString,"%ld-%ld-%ldT%ld:%ld:%ld.%ld.%ld.%ld.%ldZ",
-             &year,&month,&day,&hour,&minute,&second,&msec,&usec,&nsec,&psec) 
-      != 10) {
+  if (sscanf(inString,"%4ld-%2ld-%2ld%c%2ld:%2ld:%2ld.%3ld.%3ld.%3ld.%3ld%c",
+             &year,&month,&day,&T,&hour,&minute,&second,&msec,&usec,&nsec,
+             &psec,&Z) < 7) {
     return ILLEGAL_EPOCH_VALUE;
   }
   if (year == 9999 && month == 12 && day == 31 && hour == 23 && minute == 59 &&
@@ -396,14 +690,25 @@ double epoch[2];
 *		1993-10-10T23:45:49.999
 *
 * The expected format is the same as that produced by encodeEPOCH4.
+* If an "Nan" string is detected, then a value of NAN is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX double parseEPOCH4 (inString)
 char *inString;
 {
   long year, month, day, hour, minute, second, msec;
-  if (sscanf(inString,"%ld-%ld-%ldT%ld:%ld:%ld.%ld",
-	     &year,&month,&day,&hour,&minute,&second,&msec) != 7) {
+  char T;
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     return NAN;
+#else
+     int zero = 0;
+     return (0.0 / zero);
+#endif
+  }
+  msec = 0L;
+  if (sscanf(inString,"%4ld-%2ld-%2ld%c%2ld:%2ld:%2ld.%3ld",
+	     &year,&month,&day,&T,&hour,&minute,&second,&msec) < 7) {
     return ILLEGAL_EPOCH_VALUE;
   }
   return computeEPOCH (year, month, day, hour, minute, second, msec);
@@ -419,6 +724,7 @@ char *inString;
 *               1993-10-10T23:45:49.999999999999
 *
 * The expected format is the same as that produced by encodeEPOCH16_4.
+* If an "Nan" string is detected, then a value of NAN is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX double parseEPOCH16_4 (inString, epoch)
@@ -426,13 +732,24 @@ char *inString;
 double epoch[2];
 {
   long year, month, day, hour, minute, second, msec, usec, nsec, psec;
-  int len;
+  int len; char T;
   double mmm;
+  if (CDFstrstrIgCase(inString, "nan") != NULL) {
+#if !defined(win32) && !defined(vms)
+     epoch[0] = epoch[1] = NAN;
+     return 0.0;
+#else
+     int zero = 0;
+     epoch[0] = 0.0 / zero;
+     epoch[1] = 0.0 / zero;
+     return 0.0;
+#endif
+  }
+  msec = usec = nsec = psec = 0L;
   len = strlen(inString);
-  if (len < EPOCH16_4_STRING_LEN) return ILLEGAL_EPOCH_VALUE;
-  if (sscanf(inString,"%ld-%ld-%ldT%ld:%ld:%ld.%3ld%3ld%3ld%3ld",
-             &year,&month,&day,&hour,&minute,&second,&msec,&usec,&nsec,&psec) 
-      != 10) {
+  if (sscanf(inString,"%4ld-%2ld-%2ld%c%2ld:%2ld:%2ld.%3ld%3ld%3ld%3ld",
+             &year,&month,&day,&T,&hour,&minute,&second,&msec,&usec,&nsec,
+             &psec) < 7) {
     return ILLEGAL_EPOCH_VALUE;
   }
   if (year == 9999 && month == 12 && day == 31 && hour == 23 && minute == 59 &&
@@ -450,6 +767,153 @@ double epoch[2];
   return (double) 0.0;
 }
 
+/******************************************************************************
+* toEncodeEPOCH.
+* Converts an EPOCH value into a readable date/time string, based on the
+* passed style. If the style is not a valid one, then style 4 is assumed.
+*
+* Style: 0	dd-mmm-yyyy hh:mm:ss.ccc
+* Examples:	01-Apr-1990 03:05:02.000
+*		10-Oct-1993 23:45:49.999
+*
+* Style: 1      yyyymmdd.ttttttt
+* Examples:     19900401.3658893
+*               19931010.0000000
+*
+* Style: 2      yyyymmddhhmmss
+* Examples:     19900401030502
+*               19931010234549
+*
+* Style: 3      yyyy-mm-ddThh:mm:ss.mmmZ
+* Examples:     1990-04-01T03:05:02.000Z
+*               1993-10-10T23:45:49.999Z
+*
+* Style: 4      yyyy-mm-ddThh:mm:ss.mmm
+* Examples:     1990-04-01T03:05:02.000
+*               1993-10-10T23:45:49.999
+*
+* If an epoch value of Nan is encountered, then it returned 'Nan'
+******************************************************************************/
+VISIBLE_PREFIX void toEncodeEPOCH (double epoch, int style, char *epString)
+{
+  if (isnan(epoch)) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+  if (style < 0 || style > 4) style = 4;
+  if (style == 0) encodeEPOCH (epoch, epString);
+  else if (style == 1) encodeEPOCH1 (epoch, epString);
+  else if (style == 2) encodeEPOCH2 (epoch, epString);
+  else if (style == 3) encodeEPOCH3 (epoch, epString);
+  else if (style == 4) encodeEPOCH4 (epoch, epString);
+  return;
+}
+
+/******************************************************************************
+* EPOCHtoUnixTime.
+* Converts an array of EPOCH times (milliseconds from 0000-01-01 00:00:00.000)
+* in double to unix times (seconds from 1970-01-01 00:00:00 UTC) in double.
+*
+******************************************************************************/
+
+VISIBLE_PREFIX void EPOCHtoUnixTime (epoch, unixTime, numTimes)
+double *epoch;
+double *unixTime;
+int    numTimes;
+{
+  int i;
+  for (i = 0; i < numTimes; ++i)
+    *(unixTime+i) = (*(epoch+i) - BeginUnixTimeEPOCH) / 1000.0;
+}
+
+/******************************************************************************
+* UnixTimetoEPOCH.
+* Converts an array of unix times (seconds from 1970-01-01 00:00:00 UTC) in
+* double to EPOCH times (milliseconds from 0000-01-01 00:00:00.000) in double.
+*
+******************************************************************************/
+
+VISIBLE_PREFIX void UnixTimetoEPOCH (unixTime, epoch, numTimes)
+double *unixTime;
+double *epoch;
+int    numTimes;
+{
+  int i;
+  double milsecs; long long seconds; 
+  for (i = 0; i < numTimes; ++i) {
+    seconds = (long long) *(unixTime+i);
+    milsecs = (*(unixTime+i) - seconds) * 1000.0;
+    if ((milsecs - (int) milsecs) > 0.5) milsecs = milsecs + 1.0;
+    *(epoch+i) = seconds * 1000.0 + (int) milsecs + BeginUnixTimeEPOCH;
+  }
+}
+
+/******************************************************************************
+* EPOCH16toUnixTime.
+* Converts an array of EPOCH16 times (picoseconds from 
+* 0000-01-01 00:00:00.000.000.000.000) in doubles to unix times (seconds from
+* 1970-01-01 00:00:00 UTC) in doubles.
+*
+******************************************************************************/
+
+VISIBLE_PREFIX void EPOCH16toUnixTime (epoch, unixTime, numTimes)
+double *epoch;
+double *unixTime;
+int    numTimes;
+{
+  int i; double microsecs; int digits;
+  for (i = 0; i < numTimes; ++i) {
+    if (isnan(epoch[2*i]) || isnan(epoch[2*i+1])) {
+#if !defined(win32) && !defined(vms)
+       *(unixTime+i) = NAN;
+#else
+       int zero = 0;
+       *(unixTime+i) = 0.0 / zero;
+#endif
+    } else {
+      microsecs = epoch[2*i+1] * pow(10.0, -6.0);
+      digits = (int) microsecs;
+      if ((microsecs - digits) > 0.5) digits += 1;
+      *(unixTime+i) = epoch[2*i] - BeginUnixTimeEPOCH16 +
+                      digits * pow(10.0, -6.0);
+    }
+  }
+}
+
+/******************************************************************************
+* UnixTimetoEPOCH16.
+* Converts an array of unix times (seconds from 1970-01-01 00:00:00 UTC) in
+* double to an array of EPOCH16 times (picoseconds from 
+* 0000-01-01 00:00:00.000.000.000.000) in doubles.
+*
+******************************************************************************/
+
+VISIBLE_PREFIX void UnixTimetoEPOCH16 (unixTime, epoch, numTimes)
+double *unixTime;
+double *epoch;
+int    numTimes;
+{
+  int i, micsecs; long long part1; double submics;
+  for (i = 0; i < numTimes; ++i) {
+    if (isnan(*(unixTime+i))) {
+#if !defined(win32) && !defined(vms)
+       *(epoch+2*i) = *(epoch+2*i+1) = NAN;
+#else
+       int zero = 0;
+       *(epoch+2*i) = 0.0 / zero;
+       *(epoch+2*i+1) = 0.0 / zero;
+#endif
+    } else {
+      part1 = (long long) unixTime[i];
+      *(epoch+2*i) = part1 + BeginUnixTimeEPOCH16;
+      submics = (unixTime[i] - part1) * pow(10.0, 6.0);
+      micsecs = (int) submics;
+      if ((submics - micsecs) > 0.5) micsecs = micsecs + 1;
+      *(epoch+2*i+1) = (double) micsecs * pow(10.0, 6.0);
+    }
+  }
+}
+
 /******************************************************************************
 * encodeEPOCH.
 * Converts an EPOCH value into a readable date/time string.
@@ -459,13 +923,19 @@ double epoch[2];
 *		10-Oct-1993 23:45:49.999
 *
 * This format is the same as that expected by parseEPOCH.
+* If an Nan value is detected, then a string of "Nan" is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX void encodeEPOCH (epoch, epString)
 double epoch;
 char epString[EPOCH_STRING_LEN+1];
 {
-  if (epoch == -1.0E31) {
+  if (isnan(epoch)) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+
+  if (epoch == -1.0E31 || epoch == ILLEGAL_EPOCH_VALUE) {
     strcpyX (epString, "31-Dec-9999 23:59:59.999", 0);
     return;
   }
@@ -475,6 +945,48 @@ char epString[EPOCH_STRING_LEN+1];
   return;
 }
 
+/******************************************************************************
+* toEncodeEPOCH16.
+* Converts an EPOCH16 value into a readable date/time string, based on the
+* passed style. If the style is not a valid one, then style 4 is assumed.
+*
+* Style: 0	dd-mmm-yyyy hh:mm:ss.ccc.uuu.nnn.ppp
+* Examples:	01-Apr-1990 03:05:02.000.000.000.000
+*		10-Oct-1993 23:45:49.999.999.999.999
+*
+* Style: 1      yyyymmdd.ttttttttttttttt
+* Examples:     19900401.365889301234567
+*               19931010.000000000000000
+*
+* Style: 2      yyyymmddhhmmss
+* Examples:     19900401030502
+*               19931010234549
+*
+* Style: 3      yyyy-mm-ddThh:mm:ss.mmm.uuu.nnn.pppZ
+* Examples:     1990-04-01T03:05:02.000.000.000.000Z
+*               1993-10-10T23:45:49.999.999.999.999Z
+*
+* Style: 4      yyyy-mm-ddThh:mm:ss.mmmuuunnnppp
+* Examples:     1990-04-01T03:05:02.000000000000
+*               1993-10-10T23:45:49.999999999999
+*
+* If epoch value of Nan is encountered, then a string of "Nan" is returned.
+******************************************************************************/
+VISIBLE_PREFIX void toEncodeEPOCH16 (double *epoch, int style, char *epString)
+{
+  if (isnan(*epoch) || isnan(*(epoch+1))) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+  if (style < 0 || style > 4) style = 4;
+  if (style == 0) encodeEPOCH16 (epoch, epString);
+  else if (style == 1) encodeEPOCH16_1 (epoch, epString);
+  else if (style == 2) encodeEPOCH16_2 (epoch, epString);
+  else if (style == 3) encodeEPOCH16_3 (epoch, epString);
+  else if (style == 4) encodeEPOCH16_4 (epoch, epString);
+  return;
+}
+
 /******************************************************************************
 * encodeEPOCH16.
 * This function is an extension of parseEPOCH. It is used to handle the time
@@ -486,19 +998,26 @@ char epString[EPOCH_STRING_LEN+1];
 *               10-Oct-1993 23:45:49.999.999.999.999
 *               012345678901234567890123456789012345
 * This format is the same as that expected by parseEPOCH16.
+* If an Nan value is detected, then a string of "Nan" is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX void encodeEPOCH16 (epoch, epString)
-double epoch[2];
+double *epoch;
 char epString[EPOCH16_STRING_LEN+1];
 {
   char tmp[EPOCH1_STRING_LEN+1];
 
+  if (isnan(*epoch) || isnan(*(epoch+1))) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+
   if (epoch[0] == -1.0E31 && epoch[1] == -1.0E31) {
     strcpyX (epString, "31-Dec-9999 23:59:59.999.999.999.999", 0);
     return;
   }
-
+  if (epoch[0] < 0.0) epoch[0] = 0.0;
+  if (epoch[1] < 0.0) epoch[1] = 0.0;
   encodeEPOCHx (epoch[0]*1000.0, 
 		"<dom.02>-<month>-<year> <hour>:<min>:<sec>.<fos>",
                 epString);
@@ -517,13 +1036,19 @@ char epString[EPOCH16_STRING_LEN+1];
 *		19611231.0000000
 *
 * This format is the same as that expected by parseEPOCH1.
+* If an Nan value is detected, then a string of "Nan" is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX void encodeEPOCH1 (epoch, epString)
 double epoch;
 char epString[EPOCH1_STRING_LEN+1];
 {
-  if (epoch == -1.0E31) {
+  if (isnan(epoch)) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+
+  if (epoch == -1.0E31 || epoch == ILLEGAL_EPOCH_VALUE) {
     strcpyX (epString, "99991231.9999999", 0);
     return;
   }
@@ -545,6 +1070,7 @@ char epString[EPOCH1_STRING_LEN+1];
 *               19611231.000000000000000
 *
 * This format is the same as that expected by parseEPOCH16_1.
+* If an Nan value is detected, then a string of "Nan" is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX void encodeEPOCH16_1 (epoch, epString)
@@ -553,6 +1079,11 @@ char epString[EPOCH16_1_STRING_LEN+1];
 {
   char tmp[15+1];
 
+  if (isnan(epoch[0]) || isnan(epoch[1])) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+
   if (epoch[0] == -1.0E31 && epoch[1] == -1.0E31) {
     strcpyX (epString, "99991231.999999999999999", 0);
     return;
@@ -575,13 +1106,19 @@ char epString[EPOCH16_1_STRING_LEN+1];
 *		19611231000000
 *
 * This format is the same as that expected by parseEPOCH2.
+* If an Nan value is detected, then a string of "Nan" is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX void encodeEPOCH2 (epoch, epString)
 double epoch;
 char epString[EPOCH2_STRING_LEN+1];
 {
-  if (epoch == -1.0E31) {
+  if (isnan(epoch)) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+
+  if (epoch == -1.0E31 || epoch == ILLEGAL_EPOCH_VALUE) {
     strcpyX (epString, "99991231235959", 0);
     return;
   }
@@ -601,12 +1138,18 @@ char epString[EPOCH2_STRING_LEN+1];
 *               19611231000000
 *
 * This format is the same as that expected by parseEPOCH16_2.
+* If an Nan value is detected, then a string of "Nan" is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX void encodeEPOCH16_2 (epoch, epString)
 double epoch[2];
 char epString[EPOCH16_2_STRING_LEN+1];
 {
+  if (isnan(epoch[0]) || isnan(epoch[1])) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+
   if (epoch[0] == -1.0E31 && epoch[1] == -1.0E31) {
     strcpyX (epString, "99991231235959", 0);
     return;
@@ -626,13 +1169,19 @@ char epString[EPOCH16_2_STRING_LEN+1];
 *		1993-10-10T23:45:49.999Z
 *
 * This format is the same as that expected by parseEPOCH3.
+* If an Nan value is detected, then a string of "Nan" is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX void encodeEPOCH3 (epoch, epString)
 double epoch;
 char epString[EPOCH3_STRING_LEN+1];
 {
-  if (epoch == -1.0E31) {
+  if (isnan(epoch)) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+
+  if (epoch == -1.0E31 || epoch == ILLEGAL_EPOCH_VALUE) {
     strcpyX (epString, "9999-12-31T23:59:59.999Z", 0);
     return;
   }
@@ -642,31 +1191,6 @@ char epString[EPOCH3_STRING_LEN+1];
   return;
 }
 
-/******************************************************************************
-* encodeEPOCH4.
-* Converts an EPOCH value into a readable date/time, ISO 8601 string.
-*
-* Format:       yyyy-mm-ddThh:mm:ss.ccc
-* Examples:     1990-04-01T03:05:02.000
-*               1993-10-10T23:45:49.999
-*
-* This format is the same as that expected by parseEPOCH4.
-******************************************************************************/
-
-VISIBLE_PREFIX void encodeEPOCH4 (epoch, epString)
-double epoch;
-char epString[EPOCH4_STRING_LEN+1];
-{
-  if (epoch == -1.0E31) {
-    strcpyX (epString, "9999-12-31T23:59:59.999", 0);
-    return;
-  }
-
-  encodeEPOCHx (epoch, "<year>-<mm.02>-<dom.02>T<hour>:<min>:<sec>.<fos>",
-                epString);
-  return;
-}
-
 /****************************************************************************** 
 * encodeEPOCH16_3.
 * This function is an extension of encodeEPOCH3. It is used to handle the time
@@ -677,6 +1201,7 @@ char epString[EPOCH4_STRING_LEN+1];
 *               1993-10-10T23:45:49.999.999.999.999Z
 *               012345678901234567890123456789012345
 * This format is the same as that expected by parseEPOCH16_3.
+* If an Nan value is detected, then a string of "Nan" is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX void encodeEPOCH16_3 (epoch, epString)
@@ -685,6 +1210,11 @@ char epString[EPOCH16_3_STRING_LEN+1];
 {
   char tmp[EPOCH16_3_STRING_LEN+1];
 
+  if (isnan(epoch[0]) || isnan(epoch[1])) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+
   if (epoch[0] == -1.0E31 && epoch[1] == -1.0E31) {
     strcpyX (epString, "9999-12-31T23:59:59.999.999.999.999Z", 0);
     return;
@@ -700,6 +1230,37 @@ char epString[EPOCH16_3_STRING_LEN+1];
   return;
 }
 
+/******************************************************************************
+* encodeEPOCH4.
+* Converts an EPOCH value into a readable date/time, ISO 8601 string.
+*
+* Format:       yyyy-mm-ddThh:mm:ss.ccc
+* Examples:     1990-04-01T03:05:02.000
+*               1993-10-10T23:45:49.999
+*
+* This format is the same as that expected by parseEPOCH4.
+* If an Nan value is detected, then a string of "Nan" is returned.
+******************************************************************************/
+
+VISIBLE_PREFIX void encodeEPOCH4 (epoch, epString)
+double epoch;
+char epString[EPOCH4_STRING_LEN+1];
+{
+  if (isnan(epoch)) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+
+  if (epoch == -1.0E31 || epoch == ILLEGAL_EPOCH_VALUE) {
+    strcpyX (epString, "9999-12-31T23:59:59.999", 0);
+    return;
+  }
+
+  encodeEPOCHx (epoch, "<year>-<mm.02>-<dom.02>T<hour>:<min>:<sec>.<fos>",
+                epString);
+  return;
+}
+
 /******************************************************************************
 * encodeEPOCH16_4.
 * This function is an extension of encodeEPOCH4. It is used to handle the time
@@ -711,6 +1272,7 @@ char epString[EPOCH16_3_STRING_LEN+1];
 *               1993-10-10T23:45:49.999999999999
 *               01234567890123456789012345678901
 * This format is the same as that expected by parseEPOCH16_4.
+* If an Nan value is detected, then a string of "Nan" is returned.
 ******************************************************************************/
 
 VISIBLE_PREFIX void encodeEPOCH16_4 (epoch, epString)
@@ -719,6 +1281,11 @@ char epString[EPOCH16_4_STRING_LEN+1];
 {
   char tmp[EPOCH16_4_STRING_LEN+1];
 
+  if (isnan(epoch[0]) || isnan(epoch[1])) {
+    strcpyX (epString, "Nan", 0);
+    return;
+  }
+
   if (epoch[0] == -1.0E31 && epoch[1] == -1.0E31) {
     strcpyX (epString, "9999-12-31T23:59:59.999999999999", 0);
     return;
@@ -1224,6 +1791,7 @@ char *encoded;
 {
   long msec, usec, nsec, psec;
   double mmm;
+  msec = usec = nsec = psec = 0L;
   psec = (long) fmod (epoch, (double) 1000.0);
   mmm = epoch / (double) 1000.0;
   nsec = (long) fmod (mmm, (double) 1000.0);
@@ -1415,7 +1983,7 @@ long *year, *month, *day, *hour, *minute, *second, *msec;
   long jd,i,j,k,l,n;
   double msec_AD, second_AD, minute_AD, hour_AD, day_AD;
 
-  if (epoch == -1.0E31) {
+  if (epoch == -1.0E31 || epoch == ILLEGAL_EPOCH_VALUE) {
     *year = 9999;
     *month = 12;
     *day = 31;
@@ -1692,7 +2260,7 @@ double epoch[2];
     }
   }
   if (epoch[0] < 0.0)
-    return ILLEGAL_EPOCH_VALUE;
+    return -1.0E31;
   else
     return 0.0;
 }
