@@ -569,7 +569,7 @@ vFILE *vFp;
   FILE *fp = NULL;
 #endif
   int writable;
-#if defined(unix)
+#if defined(unix) || defined(vms)
   int fileid;
 #endif
 #if defined(win32)
@@ -644,7 +644,7 @@ vFILE *vFp;
           }
 #       else
           for (i = 1; i <= MAX_TMP; i++) {
-            strcpy (tmpPath, vFp->path);
+            strcpyX (tmpPath, vFp->path, (size_t)pathLength);
             AppendToDir (tmpPath, "");
             snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
                       "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
@@ -655,21 +655,21 @@ vFILE *vFp;
 #     endif
     } else {
       char *tmpFolder = NULL;
-      strcpy (tmpPath, "");
+      strcpyX (tmpPath, "", (size_t)pathLength);
 #     if defined(unix) || defined(vms)
         tmpFolder = (char *) cdf_AllocateMemory ((size_t)pathLength + 1, NULL);
         if (tmpFolder == NULL) return FALSE;
         writable = access(".", W_OK);
         if (writable == 0) {
-          strcpy (tmpPath, TmpFileTemplate);
-          strcpy (tmpFolder, "");
+          strcpyX (tmpPath, TmpFileTemplate, (size_t)pathLength);
+          strcpyX (tmpFolder, "", (size_t)pathLength);
         } else {
 #         if defined(unix)
-            strcpy (tmpPath, "/tmp/");
-            strcpy (tmpFolder, tmpPath);
+            strcpyX (tmpPath, "/tmp/", (size_t)pathLength);
+            strcpyX (tmpFolder, tmpPath, (size_t)pathLength);
 #         else
-            strcpy (tmpPath, "SYS$SCRATCH:");
-            strcpy (tmpFolder, tmpPath);
+            strcpyX (tmpPath, "SYS$SCRATCH:", (size_t)pathLength);
+            strcpyX (tmpFolder, tmpPath, (size_t)pathLength);
 #         endif
           strcatX (tmpPath, TmpFileTemplate, 0);
         }
@@ -677,7 +677,7 @@ vFILE *vFp;
         if (fileid != -1) fp = fdopen(fileid, "w+");
         else {
           for (i = 1; i <= MAX_TMP; i++) {
-            strcpy (tmpPath, tmpFolder);
+            strcpyX (tmpPath, tmpFolder, (size_t)pathLength);
             snprintf (EofS(tmpPath), (size_t) pathLength + 1 - strlen(tmpPath),
                       "TMP%08ld.%s", (long)(rand()%100000000), vFp->scratchExt);
             if (!IsReg(tmpPath)) {
@@ -699,7 +699,7 @@ vFILE *vFp;
               int i1, i2;
               for (i = 1; i <= MAX_TMP; i++) {
                 fh = -1;
-                strcpy (tmpPath, "");
+                strcpyX (tmpPath, "", (size_t)pathLength);
                 i1 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
                 i2 = (int) (((double)rand() / (RAND_MAX + 1)) * 25) + (int) 'A';
                 snprintf (EofS(tmpPath), (size_t) pathLength + 1 -
@@ -1409,18 +1409,16 @@ vSTATS *vStats;         /* Pointer to statistics structure. */
   ****************************************************************************/
 #if defined(win32) && (_FILE_OFFSET_BITS == 64)
   if (vFp->fh != 0) {
-    if (CDF != NULL && (!CDF->readOnly || CDF->status == READ_WRITE) &&
+    if (CDF != NULL && !(CDF->readOnly || CDF->status == READ_ONLY) &&
         CDF->singleFile && (CDF->checksum != NONE_CHECKSUM)) {
-/*      if (!FLUSHv64(vFp)) error = TRUE; */
       if (!CDFAddChecksum(CDF)) error = TRUE;
     }
     if (FCLOSE64 (vFp->fh) == EOF) error = TRUE;
   }
 #else
   if (vFp->fp != NULL) {
-    if (CDF != NULL && (!CDF->readOnly || CDF->status == READ_WRITE) && 
+    if (CDF != NULL && !(CDF->readOnly || CDF->status == READ_ONLY) && 
         CDF->singleFile && (CDF->checksum != NONE_CHECKSUM)) {
-/*      if (!FLUSHv64(vFp)) error = TRUE; */
       if (!CDFAddChecksum(CDF)) error = TRUE;
     }
     if (FCLOSE64 (vFp->fp) == EOF) error = TRUE;
