@@ -64,7 +64,7 @@ C-----------------------------------------------------------------------
      .		  sArraysParmsOUT(CDF_MAX_PARMS), sArraysPctOUT,
      .		  numVars, varNums(2), recBuffer(12), recBufferOUT(12),
      .		  nRecordsOUT, nAllocOUT, fromOUT, toOUT, nLevelsOUT,
-     .		  cReserveOUT, Flag
+     .		  cReserveOUT, Flag, lastUpdated, lastUpdatedO
 
 	CHARACTER CDFNAME*(CDF_PATHNAME_LEN),
      .		  VARNAME*(CDF_VAR_NAME_LEN256),
@@ -97,7 +97,8 @@ C-----------------------------------------------------------------------
      .	     NEW_ATTRNAME(1:5)/'ATTR2'/, cType/GZIP_COMPRESSION/,
      .	     cParms(1)/9/, sRecordsType/PAD_SPARSERECORDS/,
      .	     sArraysType/NO_SPARSEARRAYS/, cReserve/150/,
-     .	     recBuffer/1,2,3,4,5,6,7,8,9,10,11,12/
+     .       recBuffer/1,2,3,4,5,6,7,8,9,10,11,12/,
+     .       lastUpdatedO/20150701/
 
 C-----------------------------------------------------------------------
 C NUL-terminate character strings.
@@ -161,6 +162,16 @@ C-----------------------------------------------------------------------
      .		             NULL_, STATUS)
 	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '2.0')
 
+C-----------------------------------------------------------------------
+C Check leap second last upadted.
+C-----------------------------------------------------------------------
+
+	STATUS = CDF_LIB (GET_, CDF_LEAPSECONDLASTUPDATED_, LASTUPDATED,
+     .                    NULL_, STATUS);
+	IF (STATUS < CDF_OK) CALL QUIT_CDF (STATUS, "2.7");
+C	IF (LASTUPDATED .NE. LASTUPDATEDO)
+C     .    CALL QUIT_CDF(STATUS, "2.7a");
+
 C-----------------------------------------------------------------------
 C Close CDF.
 C-----------------------------------------------------------------------
