@@ -67,7 +67,6 @@ int  argC;
 char *argV[];
 {
 
-CDFid id;
 CDFstatus status;
 long numDims, dimSizes[CDF_MAX_DIMS], dimIntervals[CDF_MAX_DIMS], 
      dimIndices[CDF_MAX_DIMS], dimCounts[CDF_MAX_DIMS];
@@ -324,7 +323,7 @@ switch (argC) {
   if (status < CDF_OK) return QuitCDF (CDFpath, "1.0", status, CDFpath);
 
   status = CDFlib (SELECT_, CDF_, id,
-                            CDF_READONLY_MODE_, READONLYon,
+/*                          CDF_READONLY_MODE_, READONLYon, */
                    GET_, CDF_VERSION_, &version,
                          CDF_RELEASE_, &release,
                          CDF_INCREMENT_, &increment,
@@ -405,8 +404,8 @@ switch (argC) {
         if (numgEntries <= 1) {
           if (!detect) fprintf (fp, "%s (%ld entry):\n", attrName, numgEntries);
         } else
-          if (!detect) fprintf (fp, "%s (%ld entries):\n", attrName, numgEntries);
-
+          if (!detect)
+            fprintf (fp, "%s (%ld entries):\n", attrName, numgEntries);
         j = k = 0;
         if (numgEntries > 0) {
           do {
@@ -424,7 +423,8 @@ switch (argC) {
               value = cdf_AllocateMemory ((size_t) nBytes, FatalError);
               status = CDFlib (GET_, gENTRY_DATA_, value,
                                NULL_);
-              if (status < CDF_OK) return QuitCDF (CDFpath, "5.0", status, attrName);
+              if (status < CDF_OK)
+                return QuitCDF (CDFpath, "5.0", status, attrName);
 	      if (detect) {
 		++k; ++j;
                 cdf_FreeMemory (value, FatalError);
@@ -446,12 +446,13 @@ switch (argC) {
                   else style = EPOCH3_STYLE;
                 }
                 for (ix = 0; ix < numElemsX; ++ix) {
-                  EncodeValue (dataTypeX, (char *)value+ix*CDFelemSize(dataTypeX),
+                  EncodeValue (dataTypeX,
+                               (char *)value+ix*CDFelemSize(dataTypeX),
                                tmp, style, (size_t) sizeof(tmp));
                   if (ix == 0) strcpyX (tText, tmp, 0);
                   else strcatX (tText, tmp, 255);
                   if (numElemsX > 1 && ix < (numElemsX-1))
-                    strcatX (tText, " ", 255);
+                    strcatX (tText, ", ", 255);
                 }
                 fprintf (fp, "%s\n", tText);
               }
@@ -690,7 +691,8 @@ switch (argC) {
         virtual = FALSE;
       if (virtual) {
         maxRec = GetVirtualVarMaxRecord ((long)ii, Z);
-        fprintf (fp, "%s (Virtual) (No: %d) (Recs: %ld)", varName, ii, (maxRec+1));
+        fprintf (fp, "%s (Virtual) (No: %d) (Recs: %ld)", varName, ii,
+                                                          (maxRec+1));
       } else
         fprintf (fp, "%s (No: %d) (Recs: %ld)", varName, ii, (maxRec+1));
       if (METADATADUMP && compression != NO_COMPRESSION) {
@@ -704,7 +706,9 @@ switch (argC) {
       fprintf (fp, "\n");
     }
     if (useFormat) {
-      status = GetFormatEntry (Z, (long) ii, &prtFormat);
+      status = GetFORMATEntry (id, Z, (long) ii, &prtFormat);
+      if (status == CDF_OK) RemoveLeadingBlanks (prtFormat);
+      else prtFormat = NULL;
     } else
       prtFormat = NULL;
 
@@ -740,7 +744,7 @@ switch (argC) {
           ((char *)value)[numElems] = '\0';
           strcpyX (tText, value, numElems);
         } else {
-          int style;
+          int style, toUse;
           if (TT2000dataType(dataType)) {
             if (!ziso8601) style = TT2000_3_STYLE;
             else style = TT2000_4_STYLE;
@@ -748,7 +752,15 @@ switch (argC) {
             if (!ziso8601) style = DEFAULTstyleDUMP;
             else style = EPOCH3_STYLE;
           }
-          EncodeValue (dataType, value, tText, style, (size_t) sizeof(tText));
+          if (prtFormat != NULL) {
+            if (IsHexFormat(prtFormat))
+              toUse = 0;
+            else
+              toUse = 1;
+          } else
+            toUse = 0;
+          EncodeValueFormat (dataType, value, tText, (toUse==1?prtFormat:NULL),
+                             -1, 0, style, (size_t) sizeof(tText));
         }
       } else
         pad = FALSE;
@@ -844,8 +856,8 @@ switch (argC) {
           status = CDFlib (GET_, ATTR_NAME_, attrName,
                                  BOO(Z,zENTRY_DATA_,rENTRY_DATA_), value,
                            NULL_);
-          if (status < CDF_OK) return QuitCDF (CDFpath, "15.0", status, attrName);
- 
+          if (status < CDF_OK)
+            return QuitCDF (CDFpath, "15.0", status, attrName);
           fprintf (fp, "     %s", attrName);
           ir = (int) strlen(attrName);
           if (ir < 16) Ncharacters (fp, (16-ir), ' ');
@@ -887,27 +899,22 @@ switch (argC) {
               int ip;
               int ix = CDFelemSize(dataTypeX);
               for (ip = 0; ip < numElemsX; ++ip) {
-                EncodeValue (dataTypeX, ((char *) value)+ix*ip, tText, style,
-                             (size_t) sizeof(tText));
+                EncodeValueFormat (dataTypeX, ((char *) value)+ix*ip, tText,
+                                   prtFormat, -1, 0, style,
+                                   (size_t) sizeof(tText));
                 fprintf (fp, "%s", tText);
                 if (ip != (numElemsX -1)) fprintf (fp, ", ");
               }
               fprintf (fp, "\n");
             } else {
-              if (strcmpIgCase(attrName,"fillval") == 1 ||
-                  strcmpIgCase(attrName,"validmin") == 1 ||
-                  strcmpIgCase(attrName,"validmax") == 1) {
-                if (dataType == dataTypeX || (dataType == CDF_EPOCH ||
-                                              dataType == CDF_EPOCH16 ||
-                                              dataType == CDF_TIME_TT2000))
-                  EncodeValue (dataType, value, tText, style,
-                               (size_t) sizeof(tText));
-                else
-                  EncodeValue (dataTypeX, value, tText, style,
-                               (size_t) sizeof(tText));
-              } else
+              if (dataTypeX == CDF_EPOCH || dataTypeX == CDF_EPOCH16 ||
+                  dataTypeX == CDF_TIME_TT2000)
                 EncodeValue (dataTypeX, value, tText, style,
                              (size_t) sizeof(tText));
+              else {
+                EncodeValueFormat (dataTypeX, value, tText, prtFormat, -1, 0,
+                                   style, (size_t) sizeof(tText));
+              }
               fprintf (fp, "%s\n", tText);
             }
           }
@@ -950,41 +957,38 @@ switch (argC) {
           offset = 0;
           for (k = 0, value = buffer; k <= maxRec;
                k += 1, value = (char *) value + CDFelemSize(dataType)) {
-            EncodeValue (dataType, value, tText, style,
-	                 (size_t) sizeof(tText));
+            EncodeValueFormat (dataType, value, tText, prtFormat, -1, 0, style,
+	                       (size_t) sizeof(tText));
             fprintf (fp, "  Record # %d: %s\n", (k+1), tText);
           }
         }
       } else {
+	long toRecs, ist, ien;
+        ist = startingRec - 1;
+        ien = endingRec - 1;
+        if (ist == -1) ist = 0;
+        if (ien == -1) ien = maxRec;
+        toRecs = ien - ist + 1;
+        if (ist > maxRec && detect) continue;
         if (sp == NO_SPARSERECORDS) {
-          long toRecs, ist, ien;
-          ist = startingRec - 1;
-          ien = endingRec - 1;
           handles[0] = &buffer;
-          if (ist != -1 && ist > maxRec) {
-            if (!detect) fprintf (fp, "\n");
-            continue;
-          }
-          if (ien != -1 && ien > maxRec) ien = maxRec;
-          if (ist == -1) 
-            toRecs = maxRec + 1;
-          else
-            toRecs = (ien == -1 ? maxRec : ien) - ist + 1;
           AllocateBuffers (toRecs, numDims, dimSizes, &groups, 0, 1, handles,
-                           nValueBytes, ROWmajor(majority), 5, FatalError);
+                           nValueBytes, ROWmajor(majority), 1, FatalError);
           InitHyperParmsFromAnywhere (&hyperX, &groups, numDims, &nHypers, 
-                                      &nValues, (ist == -1 ? 0 : ist));
+                                      &nValues, ist);
           if (STRINGdataType(dataType)) imore = 1;
           else imore = 0;
           nBytes = (size_t) (CDFelemSize(dataType) * (numElems + imore));
           working = cdf_AllocateMemory ((size_t) nBytes, FatalError);
           value2 = NULL;
-          if (toCol2Row) value2 = malloc((size_t)nLogValuesPerRec*nValueBytes[0]);
+          if (toCol2Row)
+            value2 = malloc((size_t)nLogValuesPerRec*nValueBytes[0]);
           for (hyperN = 0; hyperN < nHypers; hyperN++) {
             for (j = 0; j < numDims; ++j)
               if (!dimVarys[j]) hyperX.dimCounts[j] = 1;
             status = HYPER_READ (id, Z, hyperX, buffer);
-            if (status < CDF_OK) return QuitCDF(CDFpath, "16.0", status, varName);
+            if (status < CDF_OK)
+              return QuitCDF(CDFpath, "16.0", status, varName);
             if (!detect) {
               offset = 0;
               for (k = 0, value = buffer; k < nValues;
@@ -1016,23 +1020,24 @@ switch (argC) {
                     else style = EPOCH3_STYLE;
                   }
                   if (prtFormat != NULL) {
-	      	    if ((dataType == CDF_FLOAT) || (dataType == CDF_REAL4)) {
+	      	    if (FLOAT4dataType(dataType)) {
                       if (!isnan((double)*(float *)working) &&
                           *(float *)working <= DEFAULT_FLOAT_PADVALUE) {
                         EncodeValueFormat (dataType, working, tText, NULL, 0, 0,
                                            style, (size_t) sizeof(tText));
                       } else
                         EncodeValueFormat (dataType, working, tText, prtFormat,
-                                           0, 0, style, (size_t) sizeof(tText));
-		    } else if ((dataType == CDF_DOUBLE) ||
-		  	       (dataType == CDF_REAL8)) {
+                                           -1, 0, style,
+                                           (size_t) sizeof(tText));
+		    } else if (DOUBLEdataType(dataType)) {
                       if (!isnan(*(double *)working) &&
                           *(double *)working <= DEFAULT_DOUBLE_PADVALUE) {
                         EncodeValueFormat (dataType, working, tText, NULL, 0, 0,
                                            style, (size_t) sizeof(tText));
                       } else
                         EncodeValueFormat (dataType, working, tText, prtFormat, 
-                                           0, 0, style, (size_t) sizeof(tText));
+                                           -1, 0, style,
+                                           (size_t) sizeof(tText));
 		    } else if (dataType == CDF_EPOCH) {
                       if (!isnan(*(double *)working) &&
                           *(double *)working <= DEFAULT_EPOCH_PADVALUE) {
@@ -1045,23 +1050,23 @@ switch (argC) {
                       if ((!isnan(*(double *)working)) &&
                           (!isnan(*((double *)working)+1)) &&
                           *(double *)working <= DEFAULT_EPOCH16_PADVALUE &&
-                          *(((double *)working)+1) <= DEFAULT_EPOCH16_PADVALUE) {
+                          *(((double *)working)+1) <= DEFAULT_EPOCH16_PADVALUE){
                         EncodeValueFormat (dataType, working, tText, NULL, 0, 0,
                                            style, (size_t) sizeof(tText));
                       } else
                         EncodeValueFormat (dataType, working, tText, prtFormat, 
                                            0, 0, style, (size_t) sizeof(tText));
 		    } else
-                      EncodeValueFormat (dataType, working, tText, prtFormat, 0,
-                                         0, style, (size_t) sizeof(tText));
+                      EncodeValueFormat (dataType, working, tText, prtFormat,
+                                         -1, 0, style, (size_t) sizeof(tText));
                   } else {
                     if (useFormat && (precision > 0) && 
-                        (dataType == CDF_FLOAT || dataType == CDF_REAL4 ||
-                         dataType == CDF_DOUBLE || dataType == CDF_REAL8)) {
+                        (FLOAT4dataType(dataType) ||
+                         DOUBLEdataType(dataType))) {
                       char newFormat[20+1];
                       snprintf (newFormat, 20, "%%.%dg", precision);
-                      EncodeValueFormat (dataType, working, tText, newFormat, 0,
-                                         0, style, (size_t) sizeof(tText));
+                      EncodeValueFormat (dataType, working, tText, newFormat,
+                                         -1, 0, style, (size_t) sizeof(tText));
                     } else
 		      EncodeValue (dataType, working, tText, style,
 		 	           (size_t) sizeof(tText));
@@ -1069,12 +1074,22 @@ switch (argC) {
                   fprintf (fp, "%s", tText);
                 }
                 if (nValuesPerRec == 1) {
+                  if ((recVary && (status == VIRTUAL_RECORD_DATA &&
+                                   i > maxRec)) ||
+                      (!recVary && i > maxRec)) 
+                    fprintf (fp, "\t\t<== Virtual");
                   fprintf (fp, "\n");
                   continue;
                 }
                 icount++;
-                if (icount == nValuesPerRec) fprintf (fp, "]\n");
-                else fprintf (fp, ",");
+                if (icount == nValuesPerRec) {
+                  fprintf (fp, "]");
+                  if ((recVary && (status == VIRTUAL_RECORD_DATA &&
+                                   i > maxRec)) ||
+                      (!recVary && i > maxRec)) 
+                    fprintf (fp, "\t\t<== Virtual");
+                  fprintf (fp, "\n");
+                } else fprintf (fp, ",");
               }
 	    }
             IncrHyperParms (&hyperX, &groups, numDims, ROWmajor(majority),
@@ -1104,14 +1119,16 @@ switch (argC) {
                                    dimCounts,
                           NULL_);
           if (status < CDF_OK) return QuitCDF(CDFpath, "17.0", status, varName);
-          if (toCol2Row) value2 = malloc((size_t)nLogValuesPerRec*nValueBytes[0]);
-          for (k = 0; k < (int) (maxRec+1); k++) {
+          if (toCol2Row)
+            value2 = malloc((size_t)nLogValuesPerRec*nValueBytes[0]);
+          for (k = (int) ist; k <= (int) ien; k++) {
             status = CDFlib(SELECT_, BOO(Z,zVAR_RECNUMBER_,rVARs_RECNUMBER_), 
                                      (long) k,
                             GET_, BOO(Z,zVAR_HYPERDATA_,rVAR_HYPERDATA_), buffer,
                             NULL_);
 /*          if (status == VIRTUAL_RECORD_DATA) continue; */
-            if (status < CDF_OK) return QuitCDF(CDFpath, "18.0", status, varName);
+            if (status < CDF_OK)
+              return QuitCDF(CDFpath, "18.0", status, varName);
 	    if (!detect) {
               offset = 0;
               for (ir = 0, value = buffer; ir < nLogValuesPerRec;
@@ -1141,23 +1158,24 @@ switch (argC) {
                     else style = EPOCH3_STYLE;
                   }
                   if (prtFormat != NULL) {
-                    if ((dataType == CDF_FLOAT) || (dataType == CDF_REAL4)) {
+                    if (FLOAT4dataType(dataType)) {
                       if (!isnan((double)*(float *)working) &&
                           *(float *)working <= DEFAULT_FLOAT_PADVALUE) {
                         EncodeValueFormat (dataType, working, tText, NULL, 0, 0,
                                            style, (size_t) sizeof(tText));
                       } else
                         EncodeValueFormat (dataType, working, tText, prtFormat,
-                                           0, 0, style, (size_t) sizeof(tText));
-                    } else if ((dataType == CDF_DOUBLE) ||
-		  	       (dataType == CDF_REAL8)) {
+                                           -1, 0, style,
+                                           (size_t) sizeof(tText));
+                    } else if (DOUBLEdataType(dataType)) {
                       if (!isnan(*(double *)working) &&
                           *(double *)working <= DEFAULT_DOUBLE_PADVALUE) {
                         EncodeValueFormat (dataType, working, tText, NULL, 0, 0,
                                            style, (size_t) sizeof(tText));
                       } else
                         EncodeValueFormat (dataType, working, tText, prtFormat,
-                                           0, 0, style, (size_t) sizeof(tText));
+                                           -1, 0, style,
+                                           (size_t) sizeof(tText));
                     } else if (dataType == CDF_EPOCH) {
                       if (!isnan(*(double *)working) &&
                           *(double *)working <= DEFAULT_EPOCH_PADVALUE) {
@@ -1170,23 +1188,23 @@ switch (argC) {
                       if (!isnan(*(double *)working) &&
                           !isnan(*(((double *)working)+1)) &&
                           *(double *)working <= DEFAULT_EPOCH16_PADVALUE &&
-                          *(((double *)working)+1) <= DEFAULT_EPOCH16_PADVALUE) {
+                          *(((double *)working)+1) <= DEFAULT_EPOCH16_PADVALUE){
                         EncodeValueFormat (dataType, working, tText, NULL, 0, 0,
                                            style, (size_t) sizeof(tText));
                       } else
                         EncodeValueFormat (dataType, working, tText, prtFormat,
                                            0, 0, style, (size_t) sizeof(tText));
                     } else
-                      EncodeValueFormat (dataType, working, tText, prtFormat, 0,
-                                         0, style, (size_t) sizeof(tText));
+                      EncodeValueFormat (dataType, working, tText, prtFormat,
+                                         -1, 0, style, (size_t) sizeof(tText));
                   } else {
                     if (useFormat && (precision > 0) && 
-                        (dataType == CDF_FLOAT || dataType == CDF_REAL4 ||
-                         dataType == CDF_DOUBLE || dataType == CDF_REAL8)) {
+                        (FLOAT4dataType(dataType) ||
+                         DOUBLEdataType(dataType))) {
                       char newFormat[20+1];
                       snprintf (newFormat, 20, "%%.%dg", precision);
-                      EncodeValueFormat (dataType, working, tText, newFormat, 0,
-                                         0, style, (size_t) sizeof(tText));
+                      EncodeValueFormat (dataType, working, tText, newFormat,
+                                         -1, 0, style, (size_t) sizeof(tText));
                     } else
 		      EncodeValue (dataType, working, tText, style,
 		  	           (size_t) sizeof(tText));
@@ -1686,4 +1704,3 @@ double EpochScale(long dataType1, char *units) {
   return 1.0;
 }
 
-
