@@ -333,7 +333,7 @@ Logical useFormat;
 	 *********************************************************************/
 	 if (fieldN == BOO(Z,4,3)) {
 	   ItemWindow (UNDISPLAYiw, &IW);
-	   if (!EditVarEntries(Z,varN,(long)IW.NiLines)) {
+	   if (!EditVarEntries(Z,varN,(long)IW.NiLines,useFormat)) {
 	     ItemWindow (DELETEiw, &IW);
 	     return FALSE;
 	   }
@@ -778,11 +778,7 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
      * Get the FORMAT attribute entry.
      *************************************************************************/
      if (useFormat) {
-       status = GetFormatEntry (Z, varNum, &format);
-       if (!ReportStatus(status,FALSE)) {
-	 ItemWindow (DELETEiw, &IW);
-	 return FALSE;
-       }
+       status = GetFORMATEntry (id, Z, varNum, &format);
      }
      else
        format = NULL;
@@ -1240,7 +1236,7 @@ size_t width;
      if (!ziso8601) style = DEFAULTstyleEDIT;
      else style = EPOCH3_STYLE;
    }      
-   if ((dataType == CDF_FLOAT) || (dataType == CDF_REAL4)) {
+   if (FLOAT4dataType(dataType)) {
      if (!isnan((double)*(float *)binary) && 
          !isinf((double)*(float *)binary) &&
          *(float *)binary <= DEFAULT_FLOAT_PADVALUE) {
@@ -1251,7 +1247,7 @@ size_t width;
        EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
                            -BOO(virtual,availCols,0), availCols, style,
                            (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
-   } else if ((dataType == CDF_DOUBLE) || (dataType == CDF_REAL8)) {
+   } else if (DOUBLEdataType(dataType)) {
      if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
          *(double *)binary <= DEFAULT_DOUBLE_PADVALUE) {
        EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), NULL,
@@ -1285,27 +1281,27 @@ size_t width;
                            (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
    } else
      EncodeValuesFormat (dataType, numElems, binary, EofS(vLine), format,
-		         -BOO(virtual,availCols,0), availCols, style,
+		         -BOO(virtual,availCols,-1), availCols, style,
 		         (size_t) MAX_SCREENLINE_LEN+1-strlen(vLine));
    if (virtual) strcatX (vLine, virtualT, 0);
    vvLens[itemN] = strlen(&vLine[vvCols[itemN]]);
    *nItems = itemN + 1;
-   if ((dataType == CDF_FLOAT) || (dataType == CDF_REAL4)) {
+   if (FLOAT4dataType(dataType)) {
      if (!isnan((double)*(float *)binary) &&
          !isinf((double)*(float *)binary) &&
          *(float *)binary <= DEFAULT_FLOAT_PADVALUE) {
        EncodeValuesFormat (dataType, numElems, binary, vString, NULL, 0,
                            MAX_nonSTRING_VALUE_LEN, style, width);
      } else
-       EncodeValuesFormat (dataType, numElems, binary, vString, format, 0,
+       EncodeValuesFormat (dataType, numElems, binary, vString, format, -1,
                            MAX_nonSTRING_VALUE_LEN, style, width);
-   } else if ((dataType == CDF_DOUBLE) || (dataType == CDF_REAL8)) {
+   } else if (DOUBLEdataType(dataType)) {
      if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
          *(double *)binary <= DEFAULT_DOUBLE_PADVALUE) {
        EncodeValuesFormat (dataType, numElems, binary, vString, NULL, 0,
                            MAX_nonSTRING_VALUE_LEN, style, width);
      } else
-       EncodeValuesFormat (dataType, numElems, binary, vString, format, 0,
+       EncodeValuesFormat (dataType, numElems, binary, vString, format, -1,
                            MAX_nonSTRING_VALUE_LEN, style, width);
    } else if (dataType == CDF_EPOCH) {
      if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
@@ -1326,7 +1322,7 @@ size_t width;
        EncodeValuesFormat (dataType, numElems, binary, vString, format, 0,
                            MAX_nonSTRING_VALUE_LEN, style, width);
    } else           
-     EncodeValuesFormat (dataType, numElems, binary, vString, format, 0,
+     EncodeValuesFormat (dataType, numElems, binary, vString, format, -1,
 		         BOO(STRINGdataType(dataType),
 			     (int)(numElems + 3),MAX_nonSTRING_VALUE_LEN),
 		         style, width);
@@ -1747,8 +1743,8 @@ Logical center;		/* Center messages displayed? */
   long numDims, dimSizes[CDF_MAX_DIMS], recVary, dimVarys[CDF_MAX_DIMS];
   long cType, cParms[CDF_MAX_PARMS], cPct;
   long sRecordsType, sArraysType, sArraysParms[CDF_MAX_PARMS], sArraysPct;
-  void *padBinary; int pad, maxWidth; char *format, delim;
-  int style;
+  void *padBinary = NULL; int pad, maxWidth; char *format, delim;
+  int style; long dataType2, numElems2; void *fillVal = NULL;
   /****************************************************************************
   * Inquire variable.
   ****************************************************************************/
@@ -1842,48 +1838,52 @@ Logical center;		/* Center messages displayed? */
   * Encode 5th header line.
   ****************************************************************************/
   if (useFormat) {
-    status = GetFormatEntry (Z, varN, &format);
-    if (!ReportStatus(status,center)) return FALSE;
+    status = GetFORMATEntry (id, Z, varN, &format);
   }
   else
     format = NULL;
+  if (TT2000dataType(dataType)) {
+    if (!ziso8601) style = TT2000_3_STYLE;
+    else style = TT2000_4_STYLE;
+  } else {
+    if (!ziso8601) style = DEFAULTstyleEDIT;
+    else style = EPOCH3_STYLE;
+  }
   strcpyX (IW->hLines[4], " Pad value: ", 0);
   padBinary = cdf_AllocateMemory ((size_t) (numElems * CDFelemSize(dataType)),
 				  FatalError);
   status = CDFlib (GET_, VAR_PADVALUE(Z), padBinary,
 		   NULL_);
-  if (TT2000dataType(dataType)) {
-    if (!ziso8601) style = TT2000_3_STYLE;
-    else style = TT2000_4_STYLE;
-  } else { 
-    if (!ziso8601) style = DEFAULTstyleEDIT;
-    else style = EPOCH3_STYLE;
-  }      
   switch (status) {
     case NO_PADVALUE_SPECIFIED: {
-      static char defaultT[] = " (default)";
-      maxWidth = (IW->nColsTotal - 2) - strlen(IW->hLines[4]) -
-		  strlen(defaultT);
-      if (STRINGdataType(dataType)) {
-        int ix;
-        for (ix = 0; ix < (int) numElems; ++ix)
-           *(((char *) padBinary)+ix) = (char) ' ';
+        static char defaultT[] = " (default)";
+        maxWidth = (IW->nColsTotal - 2) - strlen(IW->hLines[4]) -
+		    strlen(defaultT);
+        if (STRINGdataType(dataType)) {
+          int ix;
+          for (ix = 0; ix < (int) numElems; ++ix)
+             *(((char *) padBinary)+ix) = (char) '\0';
+        }
+        EncodeValuesFormat (dataType, numElems, padBinary, EofS(IW->hLines[4]),
+			    format, -1, maxWidth, style,
+		            (size_t) sizeof(BLANKs78)-strlen(IW->hLines[4]));
+        strcatX (IW->hLines[4], defaultT, 0);
+        break;
       }
-      EncodeValuesFormat (dataType, numElems, padBinary, EofS(IW->hLines[4]),
-			  NULL, 0, maxWidth, style,
+    default: {
+        if (!ReportStatus(status,center)) return FALSE;
+        maxWidth = (IW->nColsTotal - 2) - strlen(IW->hLines[4]);
+        EncodeValuesFormat (dataType, numElems, padBinary, EofS(IW->hLines[4]),
+			  format, -1, maxWidth, style,
 		          (size_t) sizeof(BLANKs78)-strlen(IW->hLines[4]));
-      strcatX (IW->hLines[4], defaultT, 0);
-      break;
+        break;
     }
-    default:
-      if (!ReportStatus(status,center)) return FALSE;
-      maxWidth = (IW->nColsTotal - 2) - strlen(IW->hLines[4]);
-      EncodeValuesFormat (dataType, numElems, padBinary, EofS(IW->hLines[4]),
-			  NULL, 0, maxWidth, style,
-		          (size_t) sizeof(BLANKs78)-strlen(IW->hLines[4]));
-      break;
   }
-  cdf_FreeMemory (padBinary, FatalError);
+  status = GetFILLVALEntry (id, Z, varN, &dataType2, &numElems2, &fillVal);
+  if (status == CDF_OK) 
+    strcatX (IW->hLines[4], " (*Used vAttribute FILLVAL instead)", 0); 
+  if (padBinary != NULL) cdf_FreeMemory (padBinary, FatalError);
+  if (fillVal != NULL) cdf_FreeMemory (fillVal, FatalError);
   if (format != NULL) cdf_FreeMemory (format, FatalError);
   /****************************************************************************
   * Encode 6th header line.
@@ -2009,7 +2009,7 @@ Logical *created;       /* Set to TRUE if a variable is created. */
 	 if (DecodeDimensionality(PWdim.value,&numDims,dimSizes))
 	   break;
 	 else
-	   ProblemWindow ("Illegal dimensionality.", FALSE);
+	   ProblemWindow ("Illegal or bad dimensionality.", FALSE);
        }
        else {
 	 numDims = -1;
@@ -2126,8 +2126,7 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
   nBytes = (size_t) (PWt.maxChars + 1);
   PWt.value = (char *) cdf_AllocateMemory (nBytes, FatalError);
   if (useFormat) {
-    status = GetFormatEntry (zVar, varN, &format);
-    if (!ReportStatus(status,FALSE)) return FALSE;
+    status = GetFORMATEntry (id, zVar, varN, &format);
   }
   else
     format = NULL;
@@ -2138,22 +2137,22 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
     if (!ziso8601) style = DEFAULTstyleEDIT;
     else style = EPOCH3_STYLE;
   }      
-  if ((dataType == CDF_FLOAT) || (dataType == CDF_REAL4)) {
+  if (FLOAT4dataType(dataType)) {
     if (!isnan((double)*(float *)binary) &&
         !isinf((double)*(float *)binary) &&
         *(float *)binary <= DEFAULT_FLOAT_PADVALUE) {
       EncodeValuesFormat (dataType, numElems, binary, PWt.value, NULL, 0,
                           (int) nBytes-1, style, (size_t) nBytes);
     } else
-      EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, 0,
+      EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, -1,
                           (int) nBytes-1, style, (size_t) nBytes);
-  } else if ((dataType == CDF_DOUBLE) || (dataType == CDF_REAL8)) {
+  } else if (DOUBLEdataType(dataType)) {
     if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
         *(double *)binary <= DEFAULT_DOUBLE_PADVALUE) {
       EncodeValuesFormat (dataType, numElems, binary, PWt.value, NULL, 0,
                           (int) nBytes-1, style, (size_t) nBytes);
     } else
-      EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, 0,
+      EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, -1,
                           (int) nBytes-1, style, (size_t) nBytes);
   } else if (dataType == CDF_EPOCH) {
     if (!isnan(*(double *)binary) && !isinf(*(double *)binary) &&
@@ -2174,7 +2173,7 @@ Logical *changed;	/* Assumed to be initialized to FALSE by caller. */
       EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, 0,
                           (int) nBytes-1, style, (size_t) nBytes);
   } else
-    EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, 0, 
+    EncodeValuesFormat (dataType, numElems, binary, PWt.value, format, -1, 
 		        (int) nBytes-1, style, (size_t) nBytes);
   cdf_FreeMemory (binary, FatalError);
   if (format != NULL) cdf_FreeMemory (format, FatalError);
