@@ -275,7 +275,7 @@ void DisplayPadValueDefaults () {
   snprintf (text, (size_t) sizeof(text),
 	    "  CDF_UINT4: ");
   snprintf (EofS(text), (size_t) sizeof(text)-strlen(text),
-	    Int32uFORMAT, (uInt32) DEFAULT_INT4_PADVALUE);
+	    Int32uFORMAT, DEFAULT_UINT4_PADVALUE);
   snprintf (EofS(text), (size_t) sizeof(text)-strlen(text),
 	    "\n");
   WriteOutSO (text);
