@@ -32,8 +32,9 @@
 * CALCstat.  Reads each record of a variable and calculates the statistics.
 ******************************************************************************/
 
-Logical CALCstat (Var)
-struct VarStruct *Var;
+Logical CALCstat (Var, virtual)
+struct VarStructST *Var;
+int virtual;
 {
   CDFstatus status;
   long attrN;
@@ -46,6 +47,7 @@ struct VarStruct *Var;
   long nValues, valueN;
   struct GroupStruct groups;
   struct HyperStruct hyper;
+
   /****************************************************************************
   * Initialize for this variable.
   ****************************************************************************/
@@ -69,6 +71,9 @@ struct VarStruct *Var;
   else
     Var->checkMonotonicVar = FALSE;
   Var->nValueBytes = Var->numElemsV * CDFelemSize(Var->dataTypeV);
+  if (epochMonotonic) {
+    if (!virtual && !CDFepochDataType(Var->dataTypeV)) return TRUE;
+  }
   /****************************************************************************
   * Allocate memory.
   ****************************************************************************/
@@ -101,26 +106,26 @@ struct VarStruct *Var;
 					  rVARs_RECNUMBER_), hyper.recNumber,
 			       BOO(Var->Z,zVAR_RECCOUNT_,
 					  rVARs_RECCOUNT_), hyper.recCount,
-			       BOO(Var->Z,
-				   zVAR_RECINTERVAL_,
-				   rVARs_RECINTERVAL_), hyper.recInterval,
+			       BOO(Var->Z, zVAR_RECINTERVAL_,
+					   rVARs_RECINTERVAL_), hyper.recInterval,
 			       BOO(Var->Z,zVAR_DIMINDICES_,
 					  rVARs_DIMINDICES_), hyper.dimIndices,
 			       BOO(Var->Z,zVAR_DIMCOUNTS_,
 					  rVARs_DIMCOUNTS_), hyper.dimCounts,
-			       BOO(Var->Z,
-				   zVAR_DIMINTERVALS_,
-				   rVARs_DIMINTERVALS_), hyper.dimIntervals,
+			       BOO(Var->Z, zVAR_DIMINTERVALS_,
+					   rVARs_DIMINTERVALS_), hyper.dimIntervals,
 		      GET_, BOO(Var->Z,zVAR_HYPERDATA_,
 				       rVAR_HYPERDATA_), Var->buffer,
 		      NULL_);
      if (!StatusHandlerStats(status)) return FALSE;
      for (valueN = 0, Var->value = Var->buffer; valueN < nValues;
 	  valueN++, Var->value += (size_t) Var->nValueBytes) {
-	if (Var->minmaxInited)
-	  MinMaxCheck (Var);
-	else
-	  MinMaxInit (Var);
+	if (!epochMonotonic) {
+	  if (Var->minmaxInited)
+	    MinMaxCheck (Var);
+	  else
+	    MinMaxInit (Var);
+	}
 	if (Var->checkMonotonicVar) Monotonic (Var);
      }
      IncrHyperParms (&hyper, &groups, Var->numDims, ROWmajor(majority),
@@ -130,7 +135,7 @@ struct VarStruct *Var;
   /****************************************************************************
   * Display statistics.
   ****************************************************************************/
-  DISPstat (Var);
+  DISPstat (Var, virtual);
   /****************************************************************************
   * Update attribute(s) if requested.  (NOTE: macros/functions could be used).
   ****************************************************************************/
@@ -252,7 +257,7 @@ struct VarStruct *Var;
 ******************************************************************************/
 
 void MinMaxInit (Var)
-struct VarStruct *Var;
+struct VarStructST *Var;
 {
   Logical use;
   if (Var->ignoreFillsVar)
@@ -287,7 +292,7 @@ struct VarStruct *Var;
 }
 
 void MinMaxCheck (Var)
-struct VarStruct *Var;
+struct VarStructST *Var;
 {
   Logical use;
   if (Var->ignoreFillsVar)
@@ -342,9 +347,10 @@ struct VarStruct *Var;
 ******************************************************************************/
 
 void Monotonic (Var)
-struct VarStruct *Var;
+struct VarStructST *Var;
 {
   Logical use;
+
   if (Var->ignoreFillsVar)
     if (NEx(Var->value,Var->fillval,Var->dataTypeV,Var->numElemsV))
       use = TRUE;
@@ -424,3 +430,153 @@ struct VarStruct *Var;
   }
   return;
 }
+
+/******************************************************************************
+* HandleVirtual.
+******************************************************************************/
+
+Logical HandleVirtual (id, Var)
+CDFid id;
+struct VarStructST *Var;
+{
+  CDFstatus status;
+  struct VarStructST VirtualVar;
+  long numElemsE;                 /* number of elements for attribute entry */
+  void *temp;
+
+  /****************************************************************************
+  * Initialize pointers for memory to be allocated.
+  ****************************************************************************/
+  VirtualVar.buffer = NULL;
+  /****************************************************************************
+  * Find out the real variable has the epoch time values. 
+  ****************************************************************************/
+  status = CDFlib (SELECT_, ATTR_NAME_, "COMPONENT_0",
+			    BOO(Var->Z,zENTRY_,rENTRY_), Var->varN,
+		   GET_, BOO(Var->Z,zENTRY_NUMELEMS_,
+				    rENTRY_NUMELEMS_), &numElemsE,
+		         BOO(Var->Z,zENTRY_DATA_,
+				    rENTRY_DATA_), VirtualVar.varName,
+		   NULL_);
+  if (status == NO_SUCH_ENTRY) return TRUE;
+  VirtualVar.varName[(int)numElemsE] = '\0';
+  status = CDFlib (GET_, BOO(Var->Z,zVAR_NUMBER_,
+				    rVAR_NUMBER_), VirtualVar.varName,
+						   &VirtualVar.varN,
+		   NULL_);
+  if (status != CDF_OK) return FALSE;
+  status = CDFlib (SELECT_, BOO(Var->Z,zVAR_,rVAR_), VirtualVar.varN,
+		   GET_, BOO(Var->Z,zVAR_MAXREC_,
+				    rVAR_MAXREC_), &VirtualVar.varMaxRec,
+		   NULL_);
+  if (status != CDF_OK) return FALSE;
+  if (VirtualVar.varMaxRec <= 0) {
+    status = CDFlib (SELECT_, ATTR_NAME_, "COMPONENT_1",
+			      BOO(Var->Z,zENTRY_,rENTRY_), Var->varN,
+		     GET_, BOO(Var->Z,zENTRY_NUMELEMS_,
+				      rENTRY_NUMELEMS_), &numElemsE,
+		           BOO(Var->Z,zENTRY_DATA_,
+				      rENTRY_DATA_), VirtualVar.varName,
+		     NULL_);
+    if (status != CDF_OK) return FALSE;
+    VirtualVar.varName[(int)numElemsE] = '\0';
+    status = CDFlib (GET_, BOO(Var->Z,zVAR_NUMBER_,
+				      rVAR_NUMBER_), VirtualVar.varName,
+						     &VirtualVar.varN,
+		     NULL_);
+    if (status != CDF_OK) return FALSE;
+    status = CDFlib (SELECT_, BOO(Var->Z,zVAR_,rVAR_), VirtualVar.varN,
+		     GET_, BOO(Var->Z,zVAR_MAXREC_,
+				      rVAR_MAXREC_), &VirtualVar.varMaxRec,
+		     NULL_);
+    if (status != CDF_OK) return FALSE;
+  }
+  VirtualVar.validmin = NULL;
+  VirtualVar.validmax = NULL;
+  VirtualVar.fillval = NULL;
+  VirtualVar.format = NULL;
+  VirtualVar.min = NULL;
+  VirtualVar.max = NULL;
+  VirtualVar.last = NULL;
+  VirtualVar.minINrange = NULL;
+  VirtualVar.maxINrange = NULL;
+  VirtualVar.buffer = NULL;
+  VirtualVar.Z = Var->Z;
+  status = CDFlib (GET_, BOO(Var->Z,zVAR_NUMBER_,
+				    rVAR_NUMBER_), VirtualVar.varName,
+						   &VirtualVar.varN,
+		   NULL_);
+  if (status != CDF_OK) return FALSE;
+  status = CDFlib (SELECT_, BOO(Var->Z,zVAR_,rVAR_), VirtualVar.varN,
+		   GET_, BOO(Var->Z,zVAR_DATATYPE_,
+				    rVAR_DATATYPE_), &VirtualVar.dataTypeV,
+		         BOO(Var->Z,zVAR_NUMELEMS_,
+				    rVAR_NUMELEMS_), &VirtualVar.numElemsV,
+		         BOO(Var->Z,zVAR_NUMDIMS_,
+				    rVARs_NUMDIMS_), &VirtualVar.numDims,
+		         BOO(Var->Z,zVAR_DIMSIZES_,
+				    rVARs_DIMSIZES_), VirtualVar.dimSizes,
+		         BOO(Var->Z,zVAR_RECVARY_,
+				    rVAR_RECVARY_), &VirtualVar.recVary,
+		         BOO(Var->Z,zVAR_DIMVARYS_,
+				    rVAR_DIMVARYS_), VirtualVar.dimVarys,
+		         BOO(Var->Z,zVAR_MAXREC_,
+				    rVAR_MAXREC_), &VirtualVar.varMaxRec,
+		   NULL_);
+  if (status != CDF_OK) return FALSE;
+  /****************************************************************************
+  * If fill values are to be ignored, get the fill value.
+  ****************************************************************************/
+  if (ignoreFills) {
+    long dataTypeE, numElemsE;
+    status = GetFILLVALEntry (id, Var->Z, VirtualVar.varN,  &dataTypeE,
+			      &numElemsE, &(VirtualVar.fillval));
+    if (status != CDF_OK) {
+      if (status == BAD_DATA_TYPE)
+	cdf_FreeMemory (VirtualVar.fillval, FatalError);
+      VirtualVar.ignoreFillsVar = FALSE;
+    } else
+      VirtualVar.ignoreFillsVar = TRUE;
+/*
+    status = CDFlib (SELECT_, ATTR_NAME_, "FILLVAL",
+                              BOO(Var->Z,zENTRY_,rENTRY_), VirtualVar.varN,
+                     GET_, BOO(Var->Z,zENTRY_DATATYPE_,
+                                      rENTRY_DATATYPE_), &dataTypeE,
+                           BOO(Var->Z,zENTRY_NUMELEMS_,
+                                      rENTRY_NUMELEMS_), &numElemsE,
+                     NULL_);
+    if (status == NO_SUCH_ENTRY)
+      VirtualVar.ignoreFillsVar = FALSE;
+    else {
+      if (!StatusHandlerStats(status)) return FALSE;
+      temp = cdf_AllocateMemory ((size_t) (CDFelemSize(dataTypeE) * numElemsE),
+                             FatalError);
+      status = CDFlib (GET_, BOO(VirtualVar.Z,zENTRY_DATA_,rENTRY_DATA_), temp,
+                       NULL_);
+      if (!StatusHandlerStats(status)) {
+        cdf_FreeMemory (temp, FatalError);
+        return FALSE;
+      }
+      VirtualVar.fillval = cdf_AllocateMemory (
+                           (size_t) (CDFelemSize(VirtualVar.dataTypeV) *
+                                     VirtualVar.numElemsV), FatalError);
+      ConvertDataType (dataTypeE, numElemsE, temp, VirtualVar.dataTypeV,
+                       VirtualVar.numElemsV, VirtualVar.fillval);
+      cdf_FreeMemory (temp, FatalError);
+      VirtualVar.ignoreFillsVar = TRUE;
+    }
+*/
+  }
+  else
+    VirtualVar.ignoreFillsVar = FALSE;
+  /****************************************************************************
+  * Read each record and calculate statistics.
+  ****************************************************************************/
+  if (!CALCstat(&VirtualVar, TRUE)) return FALSE;
+  FreeVarMem(&VirtualVar);
+  /****************************************************************************
+  * Return - note that memory allocated will be freed by caller.
+  ****************************************************************************/
+  return TRUE;
+}
+
