@@ -91,7 +91,7 @@ char *argV[];
   long numVars, numZvars, varN, zMode = DEFAULTzModeSTATS;
   long workingCache, stageCache, compressCache;
   Logical qopError = FALSE;
-  struct VarStruct Var;
+  struct VarStructST Var;
   Logical negToPosFp0, displayStats;
   QOP *qop;
   static char *validQuals[] = {
@@ -298,8 +298,8 @@ char *argV[];
   * Open/inquire CDF.
   ****************************************************************************/
   status = CDFlib (OPEN_, CDF_, CDFpath, &id,
-		   SELECT_, CDF_READONLY_MODE_, READONLYon,
-			    CDF_zMODE_, zMode,
+/*		   SELECT_, CDF_READONLY_MODE_, READONLYon, */
+		   SELECT_, CDF_zMODE_, zMode,
 			    CDF_NEGtoPOSfp0_MODE_, BOO(negToPosFp0,
 						       NEGtoPOSfp0on,
 						       NEGtoPOSfp0off),
@@ -358,7 +358,7 @@ char *argV[];
 			NULL_);
        if (!StatusHandlerStats(status)) return FALSE;
        if (epochMonotonic && !CDFepochDataType(Var.dataTypeV)) continue;
-       if (!SetupVar(&Var)) {
+       if (!SetupVar(id, &Var)) {
 	 FreeVarMem (&Var);
 	 return FALSE;
        }
@@ -387,7 +387,7 @@ char *argV[];
 			NULL_);
        if (!StatusHandlerStats(status)) return FALSE;
        if (epochMonotonic && !CDFepochDataType(Var.dataTypeV)) continue;
-       if (!SetupVar(&Var)) {
+       if (!SetupVar(id, &Var)) {
 	 FreeVarMem (&Var);
 	 return FALSE;
        }
@@ -420,8 +420,9 @@ char *argV[];
 * SetupVar.
 ******************************************************************************/
 
-Logical SetupVar (Var)
-struct VarStruct *Var;
+Logical SetupVar (id, Var)
+CDFid id;
+struct VarStructST *Var;
 {
   CDFstatus status;
   char line[MAX_SCREENLINE_LEN+1];
@@ -505,7 +506,7 @@ struct VarStruct *Var;
 				        rENTRY_DATATYPE_), &dataType,
 		       NULL_);
       if (status != CDF_OK) return FALSE;
-      if (!HandleVirtual(Var)) return FALSE;
+      if (!HandleVirtual(id, Var)) return FALSE;
         return TRUE;
     } else {
       WriteOut (OUTfp, "          No records.\n");
@@ -579,6 +580,17 @@ struct VarStruct *Var;
   * If fill values are to be ignored, get the fill value.
   ****************************************************************************/
   if (ignoreFills) {
+    status = GetFILLVALEntry (id, Var->Z, Var->varN, &dataTypeE, &numElemsE,
+			      &(Var->fillval));
+    if (status != CDF_OK) {
+      if (status == BAD_DATA_TYPE) {
+        cdf_FreeMemory (Var->fillval, FatalError);
+        Var->fillval = NULL;
+      }
+      Var->ignoreFillsVar = FALSE;
+    } else
+      Var->ignoreFillsVar = TRUE;
+/*
     status = CDFlib (SELECT_, ATTR_, fillvalAttrN,
 			      BOO(Var->Z,zENTRY_,rENTRY_), Var->varN,
 		     GET_, BOO(Var->Z,zENTRY_DATATYPE_,
@@ -606,6 +618,7 @@ struct VarStruct *Var;
       cdf_FreeMemory (temp, FatalError);
       Var->ignoreFillsVar = TRUE;
     }
+*/
   }
   else
     Var->ignoreFillsVar = FALSE;
@@ -648,7 +661,7 @@ struct VarStruct *Var;
 ******************************************************************************/
 
 void FreeVarMem (Var)
-struct VarStruct *Var;
+struct VarStructST *Var;
 {
   if (Var->validmin != NULL) cdf_FreeMemory (Var->validmin,
 					     FatalError);
