@@ -187,44 +187,44 @@ char *argV[];
       * Check for `about' qualifier.
       ************************************************************************/
       if (qop->qualEntered[ABOUTqual]) {
-		DisplayIdentification (pgmName);
-		cdf_FreeMemory (qop, FatalError);
-		return TRUE;
+	DisplayIdentification (pgmName);
+	cdf_FreeMemory (qop, FatalError);
+	return TRUE;
       }
       /************************************************************************
       * Skeleton table pathname.
       ************************************************************************/
       if (qop->Nparms < 1) {
-		DisplayError ("Missing parameter.");
-		qopError = TRUE;
+	DisplayError ("Missing parameter.");
+	qopError = TRUE;
       }
       else
-		strcpyX (SKTpath, qop->parms[SKTPATHparm], DU_MAX_PATH_LEN);
+	strcpyX (SKTpath, qop->parms[SKTPATHparm], DU_MAX_PATH_LEN);
       /************************************************************************
       * Check for CDF pathname qualifier.
       ************************************************************************/
       if (qop->qualEntered[CDFPATHqual]) {
 	if (!ValidateQual(qop->qualOpt[CDFPATHqual], validQuals))
-		strcpyX (CDFpath, qop->qualOpt[CDFPATHqual], DU_MAX_PATH_LEN);
+	  strcpyX (CDFpath, qop->qualOpt[CDFPATHqual], DU_MAX_PATH_LEN);
 	else {
-		DisplayError ("Invalid \"cdf\" qualifier.");
-		qopError = TRUE;
+	  DisplayError ("Invalid \"cdf\" qualifier.");
+	  qopError = TRUE;
 	}
        } else
-		CDFpath[0] = NUL;
+	  CDFpath[0] = NUL;
       /************************************************************************
       * Check for `report' qualifier.  If absent, use defaults.
       ************************************************************************/
       if (qop->qualEntered[REPORTqual]) {
-		if (!ParseOptionList(3,reportTokens,qop->qualOpt[REPORTqual],report)) {
-		  DisplayError ("Illegal list of `report' options.");
-		  qopError = TRUE;
-		}
-   	   }
-   	  else {
-		report[ERRORs] = REPORTerrorsDEFAULT;
-		report[WARNs] = REPORTwarningsDEFAULT;
-		report[INFOs] = REPORTinfosDEFAULT;
+	if (!ParseOptionList(3,reportTokens,qop->qualOpt[REPORTqual],report)) {
+	  DisplayError ("Illegal list of `report' options.");
+	  qopError = TRUE;
+	}
+      }
+      else {
+	report[ERRORs] = REPORTerrorsDEFAULT;
+	report[WARNs] = REPORTwarningsDEFAULT;
+	report[INFOs] = REPORTinfosDEFAULT;
       }
       /************************************************************************
       * Check for `log', `delete', `fillval', `neg2posfp0', and `statistics'
@@ -250,29 +250,29 @@ char *argV[];
       * Check for `cache' qualifier.
       ***********************************************************************/
       if (qop->qualEntered[CACHEqual]) {
-		if (!ParseCacheSizes(qop->qualOpt[CACHEqual],
-			     &workingCache,&stageCache,&compressCache)) {	
-		  DisplayError ("Illegal cache size/type.");
-		  qopError = TRUE;
-		}
+	if (!ParseCacheSizes(qop->qualOpt[CACHEqual],
+	     &workingCache,&stageCache,&compressCache)) {	
+	  DisplayError ("Illegal cache size/type.");
+	  qopError = TRUE;
+	}
       }
       else {
-		workingCache = useDEFAULTcacheSIZE;
-		stageCache = useDEFAULTcacheSIZE;
-		compressCache = useDEFAULTcacheSIZE;
+	workingCache = useDEFAULTcacheSIZE;
+	stageCache = useDEFAULTcacheSIZE;
+	compressCache = useDEFAULTcacheSIZE;
       }
       /************************************************************************
       * Check for zMode qualifier.
       ************************************************************************/
       if (qop->qualEntered[ZMODEqual]) {
         switch (qop->qualOpt[ZMODEqual][0]) {
-		  case '0': zMode = zMODEoff; break;
-		  case '1': zMode = zMODEon1; break;
-		  case '2': zMode = zMODEon2; break;
-		  default: {
-		    DisplayError ("Illegal zMode.");
-		    qopError = TRUE;
-		  }
+	  case '0': zMode = zMODEoff; break;
+	  case '1': zMode = zMODEon1; break;
+	  case '2': zMode = zMODEon2; break;
+	  default: {
+	    DisplayError ("Illegal zMode.");
+	    qopError = TRUE;
+	  }
         }
       }
       else
@@ -1123,7 +1123,7 @@ char *item;
       long compression, compressionParms[CDF_MAX_PARMS];
       long version, release, increment;
       char cmpStr[MAX_SKTLINE_LEN+1+1];
-      strncpy(cmpStr, item, strlen(item));
+      strcpyX (cmpStr, item, (size_t) (MAX_SKTLINE_LEN+1));
       cmpStr[strlen(item)] = (char) '\0';
       compression = WhichCompression (cmpStr, &compression, compressionParms);
       if (compression == -1) {
@@ -1320,7 +1320,8 @@ char *item;
     case GaVALUEfield: {
       void *valuesB;
       long eNumElems;
-      int style;
+      int style, allocated;
+      allocated = 0;
       if (!STRINGdataType(eDataType)) {
         if (TT2000dataType(eDataType)) style = TT2000_3_STYLE;
         else  style = EPOCH0_STYLE;
@@ -1331,13 +1332,22 @@ char *item;
       }
       else {
 	eNumElems = strlen (item);
-	valuesB = item;
+        if (eNumElems != 0) valuesB = item;
+        else {
+          eNumElems = 1L;
+          allocated = 1;
+          valuesB = (void *) malloc (1);
+          *(char *)valuesB = (char) '\0';
+        }
       }
       status = CDFlib (SELECT_, gENTRY_, entryNum,
 		       PUT_, gENTRY_DATA_, eDataType, eNumElems, valuesB,
 		       NULL_);
       if (!StatusHandlerS2C(status,wriG)) return FALSE;
-      if (valuesB != item) cdf_FreeMemory (valuesB, FatalError);
+      if (allocated == 0) {
+        if (valuesB != item) cdf_FreeMemory (valuesB, FatalError);
+      } else
+        free (valuesB);
       NextSearchItem (TOKEN, PERIODmarkOrGaENTRYNUMfield);
       break;
     }
@@ -1556,10 +1566,17 @@ char *item;
 	    status = CDFlib (CREATE_, rVAR_, varName, vDataType, vNumElems,
 					     recVary, NULL, &varNum,
 			     NULL_);
+
 	  if (!StatusHandlerS2C(status,BOO(zVar,creZ,creR))) return FALSE;
+          if (mLog) {
+            char tempS[256+1];
+            snprintf (tempS, 256, "*** created var=%s\n",varName);
+            WriteOut (stdout, tempS);
+          }
 	  /********************************************************************
 	  * Check if a pad value may possibly be written with the value of the
-	  * FILLVAL attribute.  If so, we want to allocate space for it now so
+	  * FILLVAL (or _Fillval) attribute.  If so, we want to allocate space
+	  * for it now so
 	  * that the dotCDF file is not fragmented when the FILLVAL attribute
 	  * entry is encountered.  [There will have been intervening attribute
 	  * entries written which would force this rVDR/zVDR to be wasted and a
@@ -1646,10 +1663,17 @@ char *item;
 	    status = CDFlib (CREATE_, rVAR_, varName, vDataType, vNumElems,
 					     recVary, dimVarys, &varNum,
 			     NULL_);
+
 	  if (!StatusHandlerS2C(status,BOO(zVar,creZ,creR))) return FALSE;
+          if (mLog) {
+            char tempS[256+1];
+            snprintf (tempS, 256, "*** created var=%s\n",varName);
+            WriteOut (stdout, tempS);
+          }
 	  /********************************************************************
 	  * Check if a pad value may possibly be written with the value of the
-	  * FILLVAL attribute.  If so, we want to allocate space for it now so
+	  * FILLVAL (or _Fillval) attribute.  If so, we want to allocate space
+	  * for it now so
 	  * that the `.cdf' file is not fragmented when the FILLVAL attribute
 	  * entry is encountered.  [There will have been intervening attribute
 	  * entries written which would force this rVDR/zVDR to be wasted and a
@@ -1722,7 +1746,8 @@ char *item;
     case VaeVALUEfield: {
       void *eValueB;
       long eNumElems;
-      int style;
+      int style, allocated;
+      allocated = 0;
       if (!STRINGdataType(eDataType)) {
         if (TT2000dataType(eDataType)) style = TT2000_3_STYLE;
         else style = EPOCH0_STYLE;
@@ -1733,7 +1758,13 @@ char *item;
       }
       else {
 	eNumElems = strlen (item);
-	eValueB = item;
+        if (eNumElems != 0) eValueB = item;
+        else {
+          eNumElems = 1L;
+          allocated = 1;
+          eValueB = (void *) malloc (1);
+          *(char *)eValueB = (char) '\0';
+        }
       }
       zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
       status = CDFlib (PUT_, BOO(zVar,zENTRY_DATA_,rENTRY_DATA_), eDataType,
@@ -1742,7 +1773,9 @@ char *item;
 		       NULL_);
       if (!StatusHandlerS2C(status,BOO(zVar,wriVZ,wriVR))) return FALSE;
       if (useFillval) {
-	if (!strcmpITB(vAttrName,"FILLVAL")) {
+	if (!strcmpITB(vAttrName,"FILLVAL") ||
+	    (strcmpIgCase(vAttrName,"fillval") == 1) ||
+	    (strcmpIgCase(vAttrName,"_fillval") == 1)) {
 	  nBytes = (size_t) (vNumElems * CDFelemSize(vDataType));
 	  padValue = cdf_AllocateMemory (nBytes, FatalError);
 	  ConvertDataType (eDataType, eNumElems, eValueB,
@@ -1753,7 +1786,10 @@ char *item;
 	  cdf_FreeMemory (padValue, FatalError);
 	}
       }
-      if (eValueB != item) cdf_FreeMemory (eValueB, FatalError);
+      if (allocated == 0) {
+        if (eValueB != item) cdf_FreeMemory (eValueB, FatalError);
+      } else
+        free (eValueB);
       NextSearchItem (TOKEN, VaNAMEfieldOrPERIODmark);
       break;
     }
@@ -1787,7 +1823,7 @@ char *item;
     **************************************************************************/
     case LOCfieldOrVARNAMEfieldOrENDmark:
       if (!strcmp(item,"#end")) {
-	if (mLog) WriteOut (stdout, "Reading end section...");
+	if (mLog) WriteOut (stdout, "\nReading end section...");
 	fclose (SKTfp);
 	if (!CloseTheCDF()) return FALSE;
 	if (mLog) WriteOut (stdout, "success.\n");
@@ -1901,7 +1937,7 @@ char *item;
       long compression, compressionParms[CDF_MAX_PARMS];
       long version, release, increment;
       char cmpStr[MAX_SKTLINE_LEN+1+1];
-      strncpy(cmpStr, item, strlen(item));
+      strcpyX (cmpStr, item, (size_t) (MAX_SKTLINE_LEN+1));
       cmpStr[strlen(item)] = (char) '\0';
       compression = WhichCompression (cmpStr, &compression, compressionParms);
       if (compression == -1) {
@@ -2008,7 +2044,7 @@ char *item;
       zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
       status = CDFlib (PUT_, VAR_BLOCKINGFACTOR(zVar), bf,
                        NULL_);
-      if (!StatusHandlerS2C(status,spaVAR)) return FALSE; 
+      if (!StatusHandlerS2C(status,blkVAR)) return FALSE; 
       break;
     }
     /**************************************************************************
@@ -2083,7 +2119,7 @@ char *item;
         char *tmp;
         valuesB = item + 1;
         tmp = cdf_AllocateMemory (vNumElems + 1, FatalError);
-        strncpy (tmp, valuesB, (size_t) vNumElems);
+        strcpyX (tmp, valuesB, (size_t) vNumElems);
         *(tmp+vNumElems) = '\0';
         len = (int) strlen (valuesB);
         if ((len-1) < vNumElems) {
@@ -2134,8 +2170,7 @@ char *item;
 	  WriteOut (stdout, tempS);
 	  value = item;
 	}
-	else
-	  if (len < vNumElems) {
+	else if (len < vNumElems) {
 	    if (mLog) {
 	      char tempS[MAX_MSG_LEN+1];
 	      WriteOut (stdout,
@@ -2150,8 +2185,8 @@ char *item;
 	    value = cdf_AllocateMemory (nBytes, FatalError);
 	    strcpyX (value, item, (size_t) vNumElems);
 	    NulPadRight (value, (int) (vNumElems - len));
-	  }
-	  else
+	}
+	else
 	    value = item;
       }
       zVar = BOO(zSection,TRUE,(zMode > zMODEoff));
@@ -2419,7 +2454,7 @@ char *msg;
   static char errorT[] = {
     "The following ERROR condition was encountered while"
   };
-  char tempS[2*(MAX_SCREENLINE_LEN+1)];
+  char tempS[2*(99+1)+1];
   if (StatusINFO(status) && report[INFOs]) {
     CDFlib (SELECT_, CDF_STATUS_, status,
 	    GET_, STATUS_TEXT_, text,
